__all__ = [
    "TlObject",
    "Plugins",
    "ServerStats",
    "ScheduledEvent",
    "UpdateScheduledEvent",
    "AuthenticationCodeType",
    "EmailAddressAuthentication",
    "EmailAddressResetState",
    "AuthorizationState",
    "FirebaseDeviceVerificationParameters",
    "InputFile",
    "ThumbnailFormat",
    "MaskPoint",
    "StickerFormat",
    "StickerType",
    "StickerFullType",
    "PollType",
    "ProfileTab",
    "UserType",
    "BusinessAwayMessageSchedule",
    "ChatPhotoStickerType",
    "InputChatPhoto",
    "GiftResalePrice",
    "SuggestedPostPrice",
    "SuggestedPostState",
    "SuggestedPostRefundReason",
    "StarSubscriptionType",
    "AffiliateType",
    "AffiliateProgramSortOrder",
    "CanSendGiftResult",
    "UpgradedGiftOrigin",
    "UpgradedGiftAttributeId",
    "GiftForResaleOrder",
    "GiftResaleResult",
    "SentGift",
    "TransactionDirection",
    "StarTransactionType",
    "TonTransactionType",
    "GiveawayParticipantStatus",
    "GiveawayInfo",
    "GiveawayPrize",
    "EmojiStatusType",
    "ChatMemberStatus",
    "ChatMembersFilter",
    "SupergroupMembersFilter",
    "InviteLinkChatType",
    "SecretChatState",
    "MessageSender",
    "MessageReadDate",
    "MessageOrigin",
    "ReactionType",
    "PaidReactionType",
    "MessageTopic",
    "MessageEffectType",
    "MessageSendingState",
    "MessageReplyTo",
    "InputMessageReplyTo",
    "MessageSource",
    "ReportSponsoredResult",
    "NotificationSettingsScope",
    "ReactionNotificationSource",
    "ChatType",
    "ChatList",
    "ChatSource",
    "ChatAvailableReactions",
    "PublicChatType",
    "ChatActionBar",
    "KeyboardButtonType",
    "InlineKeyboardButtonType",
    "ReplyMarkup",
    "LoginUrlInfo",
    "WebAppOpenMode",
    "SavedMessagesTopicType",
    "BuiltInTheme",
    "RichText",
    "PageBlockHorizontalAlignment",
    "PageBlockVerticalAlignment",
    "PageBlock",
    "LinkPreviewAlbumMedia",
    "LinkPreviewType",
    "CollectibleItemType",
    "InputCredentials",
    "PaymentProvider",
    "PaymentFormType",
    "PaymentReceiptType",
    "InputInvoice",
    "PaidMedia",
    "PassportElementType",
    "PassportElement",
    "InputPassportElement",
    "PassportElementErrorSource",
    "InputPassportElementErrorSource",
    "MessageContent",
    "TextEntityType",
    "InputPaidMediaType",
    "MessageSchedulingState",
    "MessageSelfDestructType",
    "InputMessageContent",
    "SearchMessagesFilter",
    "SearchMessagesChatTypeFilter",
    "ChatAction",
    "UserStatus",
    "EmojiCategorySource",
    "EmojiCategoryType",
    "StoryAreaType",
    "InputStoryAreaType",
    "StoryContent",
    "InputStoryContent",
    "StoryList",
    "StoryOrigin",
    "StoryInteractionType",
    "PublicForward",
    "ChatBoostSource",
    "ResendCodeReason",
    "CallDiscardReason",
    "CallServerType",
    "CallState",
    "GroupCallVideoQuality",
    "InviteGroupCallParticipantResult",
    "GroupCallDataChannel",
    "InputGroupCall",
    "CallProblem",
    "FirebaseAuthenticationSettings",
    "ReactionUnavailabilityReason",
    "DiceStickers",
    "SpeechRecognitionResult",
    "BotWriteAccessAllowReason",
    "TargetChat",
    "InputInlineQueryResult",
    "InlineQueryResult",
    "InlineQueryResultsButtonType",
    "CallbackQueryPayload",
    "ChatEventAction",
    "LanguagePackStringValue",
    "PremiumLimitType",
    "PremiumFeature",
    "BusinessFeature",
    "PremiumStoryFeature",
    "PremiumSource",
    "StorePaymentPurpose",
    "StoreTransaction",
    "TelegramPaymentPurpose",
    "DeviceToken",
    "BackgroundFill",
    "BackgroundType",
    "InputBackground",
    "ChatTheme",
    "InputChatTheme",
    "CanPostStoryResult",
    "CanTransferOwnershipResult",
    "CheckChatUsernameResult",
    "CheckStickerSetNameResult",
    "ResetPasswordResult",
    "MessageFileType",
    "PushMessageContent",
    "NotificationType",
    "NotificationGroupType",
    "OptionValue",
    "JsonValue",
    "StoryPrivacySettings",
    "UserPrivacySettingRule",
    "UserPrivacySetting",
    "CanSendMessageToUserResult",
    "SessionType",
    "ReportReason",
    "ReportChatResult",
    "ReportStoryResult",
    "InternalLinkType",
    "BlockList",
    "FileType",
    "NetworkType",
    "NetworkStatisticsEntry",
    "AutosaveSettingsScope",
    "ConnectionState",
    "TopChatCategory",
    "TMeUrlType",
    "SuggestedAction",
    "TextParseMode",
    "ProxyType",
    "StatisticalGraph",
    "ChatStatisticsObjectType",
    "ChatStatistics",
    "RevenueWithdrawalState",
    "ChatRevenueTransactionType",
    "VectorPathCommand",
    "BotCommandScope",
    "PhoneNumberCodeType",
    "Update",
    "LogStream",
    "Error",
    "Ok",
    "AuthenticationCodeTypeTelegramMessage",
    "AuthenticationCodeTypeSms",
    "AuthenticationCodeTypeSmsWord",
    "AuthenticationCodeTypeSmsPhrase",
    "AuthenticationCodeTypeCall",
    "AuthenticationCodeTypeFlashCall",
    "AuthenticationCodeTypeMissedCall",
    "AuthenticationCodeTypeFragment",
    "AuthenticationCodeTypeFirebaseAndroid",
    "AuthenticationCodeTypeFirebaseIos",
    "AuthenticationCodeInfo",
    "EmailAddressAuthenticationCodeInfo",
    "EmailAddressAuthenticationCode",
    "EmailAddressAuthenticationAppleId",
    "EmailAddressAuthenticationGoogleId",
    "EmailAddressResetStateAvailable",
    "EmailAddressResetStatePending",
    "TextEntity",
    "TextEntities",
    "FormattedText",
    "TermsOfService",
    "AuthorizationStateWaitTdlibParameters",
    "AuthorizationStateWaitPhoneNumber",
    "AuthorizationStateWaitPremiumPurchase",
    "AuthorizationStateWaitEmailAddress",
    "AuthorizationStateWaitEmailCode",
    "AuthorizationStateWaitCode",
    "AuthorizationStateWaitOtherDeviceConfirmation",
    "AuthorizationStateWaitRegistration",
    "AuthorizationStateWaitPassword",
    "AuthorizationStateReady",
    "AuthorizationStateLoggingOut",
    "AuthorizationStateClosing",
    "AuthorizationStateClosed",
    "FirebaseDeviceVerificationParametersSafetyNet",
    "FirebaseDeviceVerificationParametersPlayIntegrity",
    "PasswordState",
    "RecoveryEmailAddress",
    "TemporaryPasswordState",
    "LocalFile",
    "RemoteFile",
    "File",
    "InputFileId",
    "InputFileRemote",
    "InputFileLocal",
    "InputFileGenerated",
    "PhotoSize",
    "Minithumbnail",
    "ThumbnailFormatJpeg",
    "ThumbnailFormatGif",
    "ThumbnailFormatMpeg4",
    "ThumbnailFormatPng",
    "ThumbnailFormatTgs",
    "ThumbnailFormatWebm",
    "ThumbnailFormatWebp",
    "Thumbnail",
    "MaskPointForehead",
    "MaskPointEyes",
    "MaskPointMouth",
    "MaskPointChin",
    "MaskPosition",
    "StickerFormatWebp",
    "StickerFormatTgs",
    "StickerFormatWebm",
    "StickerTypeRegular",
    "StickerTypeMask",
    "StickerTypeCustomEmoji",
    "StickerFullTypeRegular",
    "StickerFullTypeMask",
    "StickerFullTypeCustomEmoji",
    "ClosedVectorPath",
    "Outline",
    "PollOption",
    "PollTypeRegular",
    "PollTypeQuiz",
    "ChecklistTask",
    "InputChecklistTask",
    "Checklist",
    "InputChecklist",
    "Animation",
    "Audio",
    "Audios",
    "Document",
    "Photo",
    "Sticker",
    "Video",
    "VideoNote",
    "VoiceNote",
    "AnimatedEmoji",
    "Contact",
    "Location",
    "Venue",
    "Game",
    "WebApp",
    "Poll",
    "AlternativeVideo",
    "VideoStoryboard",
    "Background",
    "Backgrounds",
    "ChatBackground",
    "ProfilePhoto",
    "ChatPhotoInfo",
    "ProfileTabPosts",
    "ProfileTabGifts",
    "ProfileTabMedia",
    "ProfileTabFiles",
    "ProfileTabLinks",
    "ProfileTabMusic",
    "ProfileTabVoice",
    "ProfileTabGifs",
    "UserTypeRegular",
    "UserTypeDeleted",
    "UserTypeBot",
    "UserTypeUnknown",
    "BotCommand",
    "BotCommands",
    "BotMenuButton",
    "BotVerificationParameters",
    "BotVerification",
    "VerificationStatus",
    "ChatLocation",
    "Birthdate",
    "CloseBirthdayUser",
    "BusinessAwayMessageScheduleAlways",
    "BusinessAwayMessageScheduleOutsideOfOpeningHours",
    "BusinessAwayMessageScheduleCustom",
    "BusinessLocation",
    "BusinessRecipients",
    "BusinessAwayMessageSettings",
    "BusinessGreetingMessageSettings",
    "BusinessBotRights",
    "BusinessConnectedBot",
    "BusinessStartPage",
    "InputBusinessStartPage",
    "BusinessOpeningHoursInterval",
    "BusinessOpeningHours",
    "BusinessInfo",
    "BusinessChatLink",
    "BusinessChatLinks",
    "InputBusinessChatLink",
    "BusinessChatLinkInfo",
    "ChatPhotoStickerTypeRegularOrMask",
    "ChatPhotoStickerTypeCustomEmoji",
    "ChatPhotoSticker",
    "AnimatedChatPhoto",
    "ChatPhoto",
    "ChatPhotos",
    "InputChatPhotoPrevious",
    "InputChatPhotoStatic",
    "InputChatPhotoAnimation",
    "InputChatPhotoSticker",
    "ChatPermissions",
    "ChatAdministratorRights",
    "GiftResalePriceStar",
    "GiftResalePriceTon",
    "SuggestedPostPriceStar",
    "SuggestedPostPriceTon",
    "SuggestedPostStatePending",
    "SuggestedPostStateApproved",
    "SuggestedPostStateDeclined",
    "SuggestedPostInfo",
    "InputSuggestedPostInfo",
    "SuggestedPostRefundReasonPostDeleted",
    "SuggestedPostRefundReasonPaymentRefunded",
    "StarAmount",
    "StarSubscriptionTypeChannel",
    "StarSubscriptionTypeBot",
    "StarSubscriptionPricing",
    "StarSubscription",
    "StarSubscriptions",
    "AffiliateTypeCurrentUser",
    "AffiliateTypeBot",
    "AffiliateTypeChannel",
    "AffiliateProgramSortOrderProfitability",
    "AffiliateProgramSortOrderCreationDate",
    "AffiliateProgramSortOrderRevenue",
    "AffiliateProgramParameters",
    "AffiliateProgramInfo",
    "AffiliateInfo",
    "FoundAffiliateProgram",
    "FoundAffiliatePrograms",
    "ConnectedAffiliateProgram",
    "ConnectedAffiliatePrograms",
    "ProductInfo",
    "PremiumPaymentOption",
    "PremiumStatePaymentOption",
    "PremiumGiftPaymentOption",
    "PremiumGiftPaymentOptions",
    "PremiumGiveawayPaymentOption",
    "PremiumGiveawayPaymentOptions",
    "PremiumGiftCodeInfo",
    "StarPaymentOption",
    "StarPaymentOptions",
    "StarGiveawayWinnerOption",
    "StarGiveawayPaymentOption",
    "StarGiveawayPaymentOptions",
    "AcceptedGiftTypes",
    "GiftSettings",
    "GiftPurchaseLimits",
    "GiftResaleParameters",
    "GiftCollection",
    "GiftCollections",
    "CanSendGiftResultOk",
    "CanSendGiftResultFail",
    "UpgradedGiftOriginUpgrade",
    "UpgradedGiftOriginTransfer",
    "UpgradedGiftOriginResale",
    "UpgradedGiftOriginPrepaidUpgrade",
    "UpgradedGiftModel",
    "UpgradedGiftSymbol",
    "UpgradedGiftBackdropColors",
    "UpgradedGiftBackdrop",
    "UpgradedGiftOriginalDetails",
    "Gift",
    "UpgradedGift",
    "UpgradedGiftValueInfo",
    "UpgradeGiftResult",
    "AvailableGift",
    "AvailableGifts",
    "UpgradedGiftAttributeIdModel",
    "UpgradedGiftAttributeIdSymbol",
    "UpgradedGiftAttributeIdBackdrop",
    "UpgradedGiftModelCount",
    "UpgradedGiftSymbolCount",
    "UpgradedGiftBackdropCount",
    "GiftForResaleOrderPrice",
    "GiftForResaleOrderPriceChangeDate",
    "GiftForResaleOrderNumber",
    "GiftForResale",
    "GiftsForResale",
    "GiftResaleResultOk",
    "GiftResaleResultPriceIncreased",
    "SentGiftRegular",
    "SentGiftUpgraded",
    "ReceivedGift",
    "ReceivedGifts",
    "GiftUpgradePreview",
    "TransactionDirectionIncoming",
    "TransactionDirectionOutgoing",
    "StarTransactionTypePremiumBotDeposit",
    "StarTransactionTypeAppStoreDeposit",
    "StarTransactionTypeGooglePlayDeposit",
    "StarTransactionTypeFragmentDeposit",
    "StarTransactionTypeUserDeposit",
    "StarTransactionTypeGiveawayDeposit",
    "StarTransactionTypeFragmentWithdrawal",
    "StarTransactionTypeTelegramAdsWithdrawal",
    "StarTransactionTypeTelegramApiUsage",
    "StarTransactionTypeBotPaidMediaPurchase",
    "StarTransactionTypeBotPaidMediaSale",
    "StarTransactionTypeChannelPaidMediaPurchase",
    "StarTransactionTypeChannelPaidMediaSale",
    "StarTransactionTypeBotInvoicePurchase",
    "StarTransactionTypeBotInvoiceSale",
    "StarTransactionTypeBotSubscriptionPurchase",
    "StarTransactionTypeBotSubscriptionSale",
    "StarTransactionTypeChannelSubscriptionPurchase",
    "StarTransactionTypeChannelSubscriptionSale",
    "StarTransactionTypeGiftPurchase",
    "StarTransactionTypeGiftTransfer",
    "StarTransactionTypeGiftSale",
    "StarTransactionTypeGiftUpgrade",
    "StarTransactionTypeGiftUpgradePurchase",
    "StarTransactionTypeUpgradedGiftPurchase",
    "StarTransactionTypeUpgradedGiftSale",
    "StarTransactionTypeChannelPaidReactionSend",
    "StarTransactionTypeChannelPaidReactionReceive",
    "StarTransactionTypeAffiliateProgramCommission",
    "StarTransactionTypePaidMessageSend",
    "StarTransactionTypePaidMessageReceive",
    "StarTransactionTypeSuggestedPostPaymentSend",
    "StarTransactionTypeSuggestedPostPaymentReceive",
    "StarTransactionTypePremiumPurchase",
    "StarTransactionTypeBusinessBotTransferSend",
    "StarTransactionTypeBusinessBotTransferReceive",
    "StarTransactionTypePublicPostSearch",
    "StarTransactionTypeUnsupported",
    "StarTransaction",
    "StarTransactions",
    "TonTransactionTypeFragmentDeposit",
    "TonTransactionTypeSuggestedPostPayment",
    "TonTransactionTypeUpgradedGiftPurchase",
    "TonTransactionTypeUpgradedGiftSale",
    "TonTransactionTypeUnsupported",
    "TonTransaction",
    "TonTransactions",
    "GiveawayParticipantStatusEligible",
    "GiveawayParticipantStatusParticipating",
    "GiveawayParticipantStatusAlreadyWasMember",
    "GiveawayParticipantStatusAdministrator",
    "GiveawayParticipantStatusDisallowedCountry",
    "GiveawayInfoOngoing",
    "GiveawayInfoCompleted",
    "GiveawayPrizePremium",
    "GiveawayPrizeStars",
    "AccentColor",
    "ProfileAccentColors",
    "ProfileAccentColor",
    "UserRating",
    "RestrictionInfo",
    "EmojiStatusTypeCustomEmoji",
    "EmojiStatusTypeUpgradedGift",
    "EmojiStatus",
    "EmojiStatuses",
    "EmojiStatusCustomEmojis",
    "Usernames",
    "User",
    "BotInfo",
    "UserFullInfo",
    "Users",
    "FoundUsers",
    "ChatAdministrator",
    "ChatAdministrators",
    "ChatMemberStatusCreator",
    "ChatMemberStatusAdministrator",
    "ChatMemberStatusMember",
    "ChatMemberStatusRestricted",
    "ChatMemberStatusLeft",
    "ChatMemberStatusBanned",
    "ChatMember",
    "ChatMembers",
    "ChatMembersFilterContacts",
    "ChatMembersFilterAdministrators",
    "ChatMembersFilterMembers",
    "ChatMembersFilterMention",
    "ChatMembersFilterRestricted",
    "ChatMembersFilterBanned",
    "ChatMembersFilterBots",
    "SupergroupMembersFilterRecent",
    "SupergroupMembersFilterContacts",
    "SupergroupMembersFilterAdministrators",
    "SupergroupMembersFilterSearch",
    "SupergroupMembersFilterRestricted",
    "SupergroupMembersFilterBanned",
    "SupergroupMembersFilterMention",
    "SupergroupMembersFilterBots",
    "ChatInviteLink",
    "ChatInviteLinks",
    "ChatInviteLinkCount",
    "ChatInviteLinkCounts",
    "ChatInviteLinkMember",
    "ChatInviteLinkMembers",
    "InviteLinkChatTypeBasicGroup",
    "InviteLinkChatTypeSupergroup",
    "InviteLinkChatTypeChannel",
    "ChatInviteLinkSubscriptionInfo",
    "ChatInviteLinkInfo",
    "ChatJoinRequest",
    "ChatJoinRequests",
    "ChatJoinRequestsInfo",
    "BasicGroup",
    "BasicGroupFullInfo",
    "Supergroup",
    "SupergroupFullInfo",
    "SecretChatStatePending",
    "SecretChatStateReady",
    "SecretChatStateClosed",
    "SecretChat",
    "PublicPostSearchLimits",
    "MessageSenderUser",
    "MessageSenderChat",
    "MessageSenders",
    "ChatMessageSender",
    "ChatMessageSenders",
    "MessageReadDateRead",
    "MessageReadDateUnread",
    "MessageReadDateTooOld",
    "MessageReadDateUserPrivacyRestricted",
    "MessageReadDateMyPrivacyRestricted",
    "MessageViewer",
    "MessageViewers",
    "MessageOriginUser",
    "MessageOriginHiddenUser",
    "MessageOriginChat",
    "MessageOriginChannel",
    "ForwardSource",
    "ReactionTypeEmoji",
    "ReactionTypeCustomEmoji",
    "ReactionTypePaid",
    "PaidReactionTypeRegular",
    "PaidReactionTypeAnonymous",
    "PaidReactionTypeChat",
    "PaidReactor",
    "MessageForwardInfo",
    "MessageImportInfo",
    "MessageReplyInfo",
    "MessageReaction",
    "MessageReactions",
    "MessageInteractionInfo",
    "UnreadReaction",
    "MessageTopicForum",
    "MessageTopicDirectMessages",
    "MessageTopicSavedMessages",
    "MessageEffectTypeEmojiReaction",
    "MessageEffectTypePremiumSticker",
    "MessageEffect",
    "MessageSendingStatePending",
    "MessageSendingStateFailed",
    "TextQuote",
    "InputTextQuote",
    "MessageReplyToMessage",
    "MessageReplyToStory",
    "InputMessageReplyToMessage",
    "InputMessageReplyToExternalMessage",
    "InputMessageReplyToStory",
    "FactCheck",
    "Message",
    "Messages",
    "FoundMessages",
    "FoundChatMessages",
    "FoundPublicPosts",
    "MessagePosition",
    "MessagePositions",
    "MessageCalendarDay",
    "MessageCalendar",
    "BusinessMessage",
    "BusinessMessages",
    "MessageSourceChatHistory",
    "MessageSourceMessageThreadHistory",
    "MessageSourceForumTopicHistory",
    "MessageSourceDirectMessagesChatTopicHistory",
    "MessageSourceHistoryPreview",
    "MessageSourceChatList",
    "MessageSourceSearch",
    "MessageSourceChatEventLog",
    "MessageSourceNotification",
    "MessageSourceScreenshot",
    "MessageSourceOther",
    "AdvertisementSponsor",
    "SponsoredMessage",
    "SponsoredMessages",
    "SponsoredChat",
    "SponsoredChats",
    "VideoMessageAdvertisement",
    "VideoMessageAdvertisements",
    "ReportOption",
    "ReportSponsoredResultOk",
    "ReportSponsoredResultFailed",
    "ReportSponsoredResultOptionRequired",
    "ReportSponsoredResultAdsHidden",
    "ReportSponsoredResultPremiumRequired",
    "FileDownload",
    "DownloadedFileCounts",
    "FoundFileDownloads",
    "NotificationSettingsScopePrivateChats",
    "NotificationSettingsScopeGroupChats",
    "NotificationSettingsScopeChannelChats",
    "ChatNotificationSettings",
    "ScopeNotificationSettings",
    "ReactionNotificationSourceNone",
    "ReactionNotificationSourceContacts",
    "ReactionNotificationSourceAll",
    "ReactionNotificationSettings",
    "DraftMessage",
    "ChatTypePrivate",
    "ChatTypeBasicGroup",
    "ChatTypeSupergroup",
    "ChatTypeSecret",
    "ChatFolderIcon",
    "ChatFolderName",
    "ChatFolder",
    "ChatFolderInfo",
    "ChatFolderInviteLink",
    "ChatFolderInviteLinks",
    "ChatFolderInviteLinkInfo",
    "RecommendedChatFolder",
    "RecommendedChatFolders",
    "ArchiveChatListSettings",
    "ChatListMain",
    "ChatListArchive",
    "ChatListFolder",
    "ChatLists",
    "ChatSourceMtprotoProxy",
    "ChatSourcePublicServiceAnnouncement",
    "ChatPosition",
    "ChatAvailableReactionsAll",
    "ChatAvailableReactionsSome",
    "SavedMessagesTag",
    "SavedMessagesTags",
    "BusinessBotManageBar",
    "VideoChat",
    "Chat",
    "Chats",
    "FailedToAddMember",
    "FailedToAddMembers",
    "CreatedBasicGroupChat",
    "PublicChatTypeHasUsername",
    "PublicChatTypeIsLocationBased",
    "AccountInfo",
    "ChatActionBarReportSpam",
    "ChatActionBarInviteMembers",
    "ChatActionBarReportAddBlock",
    "ChatActionBarAddContact",
    "ChatActionBarSharePhoneNumber",
    "ChatActionBarJoinRequest",
    "KeyboardButtonTypeText",
    "KeyboardButtonTypeRequestPhoneNumber",
    "KeyboardButtonTypeRequestLocation",
    "KeyboardButtonTypeRequestPoll",
    "KeyboardButtonTypeRequestUsers",
    "KeyboardButtonTypeRequestChat",
    "KeyboardButtonTypeWebApp",
    "KeyboardButton",
    "InlineKeyboardButtonTypeUrl",
    "InlineKeyboardButtonTypeLoginUrl",
    "InlineKeyboardButtonTypeWebApp",
    "InlineKeyboardButtonTypeCallback",
    "InlineKeyboardButtonTypeCallbackWithPassword",
    "InlineKeyboardButtonTypeCallbackGame",
    "InlineKeyboardButtonTypeSwitchInline",
    "InlineKeyboardButtonTypeBuy",
    "InlineKeyboardButtonTypeUser",
    "InlineKeyboardButtonTypeCopyText",
    "InlineKeyboardButton",
    "ReplyMarkupRemoveKeyboard",
    "ReplyMarkupForceReply",
    "ReplyMarkupShowKeyboard",
    "ReplyMarkupInlineKeyboard",
    "LoginUrlInfoOpen",
    "LoginUrlInfoRequestConfirmation",
    "ThemeParameters",
    "WebAppOpenModeCompact",
    "WebAppOpenModeFullSize",
    "WebAppOpenModeFullScreen",
    "FoundWebApp",
    "WebAppInfo",
    "MainWebApp",
    "WebAppOpenParameters",
    "MessageThreadInfo",
    "SavedMessagesTopicTypeMyNotes",
    "SavedMessagesTopicTypeAuthorHidden",
    "SavedMessagesTopicTypeSavedFromChat",
    "SavedMessagesTopic",
    "DirectMessagesChatTopic",
    "ForumTopicIcon",
    "ForumTopicInfo",
    "ForumTopic",
    "ForumTopics",
    "LinkPreviewOptions",
    "SharedUser",
    "SharedChat",
    "BuiltInThemeClassic",
    "BuiltInThemeDay",
    "BuiltInThemeNight",
    "BuiltInThemeTinted",
    "BuiltInThemeArctic",
    "ThemeSettings",
    "RichTextPlain",
    "RichTextBold",
    "RichTextItalic",
    "RichTextUnderline",
    "RichTextStrikethrough",
    "RichTextFixed",
    "RichTextUrl",
    "RichTextEmailAddress",
    "RichTextSubscript",
    "RichTextSuperscript",
    "RichTextMarked",
    "RichTextPhoneNumber",
    "RichTextIcon",
    "RichTextReference",
    "RichTextAnchor",
    "RichTextAnchorLink",
    "RichTexts",
    "PageBlockCaption",
    "PageBlockListItem",
    "PageBlockHorizontalAlignmentLeft",
    "PageBlockHorizontalAlignmentCenter",
    "PageBlockHorizontalAlignmentRight",
    "PageBlockVerticalAlignmentTop",
    "PageBlockVerticalAlignmentMiddle",
    "PageBlockVerticalAlignmentBottom",
    "PageBlockTableCell",
    "PageBlockRelatedArticle",
    "PageBlockTitle",
    "PageBlockSubtitle",
    "PageBlockAuthorDate",
    "PageBlockHeader",
    "PageBlockSubheader",
    "PageBlockKicker",
    "PageBlockParagraph",
    "PageBlockPreformatted",
    "PageBlockFooter",
    "PageBlockDivider",
    "PageBlockAnchor",
    "PageBlockList",
    "PageBlockBlockQuote",
    "PageBlockPullQuote",
    "PageBlockAnimation",
    "PageBlockAudio",
    "PageBlockPhoto",
    "PageBlockVideo",
    "PageBlockVoiceNote",
    "PageBlockCover",
    "PageBlockEmbedded",
    "PageBlockEmbeddedPost",
    "PageBlockCollage",
    "PageBlockSlideshow",
    "PageBlockChatLink",
    "PageBlockTable",
    "PageBlockDetails",
    "PageBlockRelatedArticles",
    "PageBlockMap",
    "WebPageInstantView",
    "LinkPreviewAlbumMediaPhoto",
    "LinkPreviewAlbumMediaVideo",
    "LinkPreviewTypeAlbum",
    "LinkPreviewTypeAnimation",
    "LinkPreviewTypeApp",
    "LinkPreviewTypeArticle",
    "LinkPreviewTypeAudio",
    "LinkPreviewTypeBackground",
    "LinkPreviewTypeChannelBoost",
    "LinkPreviewTypeChat",
    "LinkPreviewTypeDirectMessagesChat",
    "LinkPreviewTypeDocument",
    "LinkPreviewTypeEmbeddedAnimationPlayer",
    "LinkPreviewTypeEmbeddedAudioPlayer",
    "LinkPreviewTypeEmbeddedVideoPlayer",
    "LinkPreviewTypeExternalAudio",
    "LinkPreviewTypeExternalVideo",
    "LinkPreviewTypeGiftCollection",
    "LinkPreviewTypeGroupCall",
    "LinkPreviewTypeInvoice",
    "LinkPreviewTypeMessage",
    "LinkPreviewTypePhoto",
    "LinkPreviewTypePremiumGiftCode",
    "LinkPreviewTypeShareableChatFolder",
    "LinkPreviewTypeSticker",
    "LinkPreviewTypeStickerSet",
    "LinkPreviewTypeStory",
    "LinkPreviewTypeStoryAlbum",
    "LinkPreviewTypeSupergroupBoost",
    "LinkPreviewTypeTheme",
    "LinkPreviewTypeUnsupported",
    "LinkPreviewTypeUpgradedGift",
    "LinkPreviewTypeUser",
    "LinkPreviewTypeVideo",
    "LinkPreviewTypeVideoChat",
    "LinkPreviewTypeVideoNote",
    "LinkPreviewTypeVoiceNote",
    "LinkPreviewTypeWebApp",
    "LinkPreview",
    "CountryInfo",
    "Countries",
    "PhoneNumberInfo",
    "CollectibleItemTypeUsername",
    "CollectibleItemTypePhoneNumber",
    "CollectibleItemInfo",
    "BankCardActionOpenUrl",
    "BankCardInfo",
    "Address",
    "LocationAddress",
    "LabeledPricePart",
    "Invoice",
    "OrderInfo",
    "ShippingOption",
    "SavedCredentials",
    "InputCredentialsSaved",
    "InputCredentialsNew",
    "InputCredentialsApplePay",
    "InputCredentialsGooglePay",
    "PaymentProviderSmartGlocal",
    "PaymentProviderStripe",
    "PaymentProviderOther",
    "PaymentOption",
    "PaymentFormTypeRegular",
    "PaymentFormTypeStars",
    "PaymentFormTypeStarSubscription",
    "PaymentForm",
    "ValidatedOrderInfo",
    "PaymentResult",
    "PaymentReceiptTypeRegular",
    "PaymentReceiptTypeStars",
    "PaymentReceipt",
    "InputInvoiceMessage",
    "InputInvoiceName",
    "InputInvoiceTelegram",
    "PaidMediaPreview",
    "PaidMediaPhoto",
    "PaidMediaVideo",
    "PaidMediaUnsupported",
    "GiveawayParameters",
    "DatedFile",
    "PassportElementTypePersonalDetails",
    "PassportElementTypePassport",
    "PassportElementTypeDriverLicense",
    "PassportElementTypeIdentityCard",
    "PassportElementTypeInternalPassport",
    "PassportElementTypeAddress",
    "PassportElementTypeUtilityBill",
    "PassportElementTypeBankStatement",
    "PassportElementTypeRentalAgreement",
    "PassportElementTypePassportRegistration",
    "PassportElementTypeTemporaryRegistration",
    "PassportElementTypePhoneNumber",
    "PassportElementTypeEmailAddress",
    "Date",
    "PersonalDetails",
    "IdentityDocument",
    "InputIdentityDocument",
    "PersonalDocument",
    "InputPersonalDocument",
    "PassportElementPersonalDetails",
    "PassportElementPassport",
    "PassportElementDriverLicense",
    "PassportElementIdentityCard",
    "PassportElementInternalPassport",
    "PassportElementAddress",
    "PassportElementUtilityBill",
    "PassportElementBankStatement",
    "PassportElementRentalAgreement",
    "PassportElementPassportRegistration",
    "PassportElementTemporaryRegistration",
    "PassportElementPhoneNumber",
    "PassportElementEmailAddress",
    "InputPassportElementPersonalDetails",
    "InputPassportElementPassport",
    "InputPassportElementDriverLicense",
    "InputPassportElementIdentityCard",
    "InputPassportElementInternalPassport",
    "InputPassportElementAddress",
    "InputPassportElementUtilityBill",
    "InputPassportElementBankStatement",
    "InputPassportElementRentalAgreement",
    "InputPassportElementPassportRegistration",
    "InputPassportElementTemporaryRegistration",
    "InputPassportElementPhoneNumber",
    "InputPassportElementEmailAddress",
    "PassportElements",
    "PassportElementErrorSourceUnspecified",
    "PassportElementErrorSourceDataField",
    "PassportElementErrorSourceFrontSide",
    "PassportElementErrorSourceReverseSide",
    "PassportElementErrorSourceSelfie",
    "PassportElementErrorSourceTranslationFile",
    "PassportElementErrorSourceTranslationFiles",
    "PassportElementErrorSourceFile",
    "PassportElementErrorSourceFiles",
    "PassportElementError",
    "PassportSuitableElement",
    "PassportRequiredElement",
    "PassportAuthorizationForm",
    "PassportElementsWithErrors",
    "EncryptedCredentials",
    "EncryptedPassportElement",
    "InputPassportElementErrorSourceUnspecified",
    "InputPassportElementErrorSourceDataField",
    "InputPassportElementErrorSourceFrontSide",
    "InputPassportElementErrorSourceReverseSide",
    "InputPassportElementErrorSourceSelfie",
    "InputPassportElementErrorSourceTranslationFile",
    "InputPassportElementErrorSourceTranslationFiles",
    "InputPassportElementErrorSourceFile",
    "InputPassportElementErrorSourceFiles",
    "InputPassportElementError",
    "MessageText",
    "MessageAnimation",
    "MessageAudio",
    "MessageDocument",
    "MessagePaidMedia",
    "MessagePhoto",
    "MessageSticker",
    "MessageVideo",
    "MessageVideoNote",
    "MessageVoiceNote",
    "MessageExpiredPhoto",
    "MessageExpiredVideo",
    "MessageExpiredVideoNote",
    "MessageExpiredVoiceNote",
    "MessageLocation",
    "MessageVenue",
    "MessageContact",
    "MessageAnimatedEmoji",
    "MessageDice",
    "MessageGame",
    "MessagePoll",
    "MessageStory",
    "MessageChecklist",
    "MessageInvoice",
    "MessageCall",
    "MessageGroupCall",
    "MessageVideoChatScheduled",
    "MessageVideoChatStarted",
    "MessageVideoChatEnded",
    "MessageInviteVideoChatParticipants",
    "MessageBasicGroupChatCreate",
    "MessageSupergroupChatCreate",
    "MessageChatChangeTitle",
    "MessageChatChangePhoto",
    "MessageChatDeletePhoto",
    "MessageChatAddMembers",
    "MessageChatJoinByLink",
    "MessageChatJoinByRequest",
    "MessageChatDeleteMember",
    "MessageChatUpgradeTo",
    "MessageChatUpgradeFrom",
    "MessagePinMessage",
    "MessageScreenshotTaken",
    "MessageChatSetBackground",
    "MessageChatSetTheme",
    "MessageChatSetMessageAutoDeleteTime",
    "MessageChatBoost",
    "MessageForumTopicCreated",
    "MessageForumTopicEdited",
    "MessageForumTopicIsClosedToggled",
    "MessageForumTopicIsHiddenToggled",
    "MessageSuggestProfilePhoto",
    "MessageCustomServiceAction",
    "MessageGameScore",
    "MessagePaymentSuccessful",
    "MessagePaymentSuccessfulBot",
    "MessagePaymentRefunded",
    "MessageGiftedPremium",
    "MessagePremiumGiftCode",
    "MessageGiveawayCreated",
    "MessageGiveaway",
    "MessageGiveawayCompleted",
    "MessageGiveawayWinners",
    "MessageGiftedStars",
    "MessageGiftedTon",
    "MessageGiveawayPrizeStars",
    "MessageGift",
    "MessageUpgradedGift",
    "MessageRefundedUpgradedGift",
    "MessagePaidMessagesRefunded",
    "MessagePaidMessagePriceChanged",
    "MessageDirectMessagePriceChanged",
    "MessageChecklistTasksDone",
    "MessageChecklistTasksAdded",
    "MessageSuggestedPostApprovalFailed",
    "MessageSuggestedPostApproved",
    "MessageSuggestedPostDeclined",
    "MessageSuggestedPostPaid",
    "MessageSuggestedPostRefunded",
    "MessageContactRegistered",
    "MessageUsersShared",
    "MessageChatShared",
    "MessageBotWriteAccessAllowed",
    "MessageWebAppDataSent",
    "MessageWebAppDataReceived",
    "MessagePassportDataSent",
    "MessagePassportDataReceived",
    "MessageProximityAlertTriggered",
    "MessageUnsupported",
    "TextEntityTypeMention",
    "TextEntityTypeHashtag",
    "TextEntityTypeCashtag",
    "TextEntityTypeBotCommand",
    "TextEntityTypeUrl",
    "TextEntityTypeEmailAddress",
    "TextEntityTypePhoneNumber",
    "TextEntityTypeBankCardNumber",
    "TextEntityTypeBold",
    "TextEntityTypeItalic",
    "TextEntityTypeUnderline",
    "TextEntityTypeStrikethrough",
    "TextEntityTypeSpoiler",
    "TextEntityTypeCode",
    "TextEntityTypePre",
    "TextEntityTypePreCode",
    "TextEntityTypeBlockQuote",
    "TextEntityTypeExpandableBlockQuote",
    "TextEntityTypeTextUrl",
    "TextEntityTypeMentionName",
    "TextEntityTypeCustomEmoji",
    "TextEntityTypeMediaTimestamp",
    "InputThumbnail",
    "InputPaidMediaTypePhoto",
    "InputPaidMediaTypeVideo",
    "InputPaidMedia",
    "MessageSchedulingStateSendAtDate",
    "MessageSchedulingStateSendWhenOnline",
    "MessageSchedulingStateSendWhenVideoProcessed",
    "MessageSelfDestructTypeTimer",
    "MessageSelfDestructTypeImmediately",
    "MessageSendOptions",
    "MessageCopyOptions",
    "InputMessageText",
    "InputMessageAnimation",
    "InputMessageAudio",
    "InputMessageDocument",
    "InputMessagePaidMedia",
    "InputMessagePhoto",
    "InputMessageSticker",
    "InputMessageVideo",
    "InputMessageVideoNote",
    "InputMessageVoiceNote",
    "InputMessageLocation",
    "InputMessageVenue",
    "InputMessageContact",
    "InputMessageDice",
    "InputMessageGame",
    "InputMessageInvoice",
    "InputMessagePoll",
    "InputMessageStory",
    "InputMessageChecklist",
    "InputMessageForwarded",
    "MessageProperties",
    "SearchMessagesFilterEmpty",
    "SearchMessagesFilterAnimation",
    "SearchMessagesFilterAudio",
    "SearchMessagesFilterDocument",
    "SearchMessagesFilterPhoto",
    "SearchMessagesFilterVideo",
    "SearchMessagesFilterVoiceNote",
    "SearchMessagesFilterPhotoAndVideo",
    "SearchMessagesFilterUrl",
    "SearchMessagesFilterChatPhoto",
    "SearchMessagesFilterVideoNote",
    "SearchMessagesFilterVoiceAndVideoNote",
    "SearchMessagesFilterMention",
    "SearchMessagesFilterUnreadMention",
    "SearchMessagesFilterUnreadReaction",
    "SearchMessagesFilterFailedToSend",
    "SearchMessagesFilterPinned",
    "SearchMessagesChatTypeFilterPrivate",
    "SearchMessagesChatTypeFilterGroup",
    "SearchMessagesChatTypeFilterChannel",
    "ChatActionTyping",
    "ChatActionRecordingVideo",
    "ChatActionUploadingVideo",
    "ChatActionRecordingVoiceNote",
    "ChatActionUploadingVoiceNote",
    "ChatActionUploadingPhoto",
    "ChatActionUploadingDocument",
    "ChatActionChoosingSticker",
    "ChatActionChoosingLocation",
    "ChatActionChoosingContact",
    "ChatActionStartPlayingGame",
    "ChatActionRecordingVideoNote",
    "ChatActionUploadingVideoNote",
    "ChatActionWatchingAnimations",
    "ChatActionCancel",
    "UserStatusEmpty",
    "UserStatusOnline",
    "UserStatusOffline",
    "UserStatusRecently",
    "UserStatusLastWeek",
    "UserStatusLastMonth",
    "EmojiKeyword",
    "EmojiKeywords",
    "Stickers",
    "Emojis",
    "StickerSet",
    "StickerSetInfo",
    "StickerSets",
    "TrendingStickerSets",
    "EmojiCategorySourceSearch",
    "EmojiCategorySourcePremium",
    "EmojiCategory",
    "EmojiCategories",
    "EmojiCategoryTypeDefault",
    "EmojiCategoryTypeRegularStickers",
    "EmojiCategoryTypeEmojiStatus",
    "EmojiCategoryTypeChatPhoto",
    "CurrentWeather",
    "StoryAreaPosition",
    "StoryAreaTypeLocation",
    "StoryAreaTypeVenue",
    "StoryAreaTypeSuggestedReaction",
    "StoryAreaTypeMessage",
    "StoryAreaTypeLink",
    "StoryAreaTypeWeather",
    "StoryAreaTypeUpgradedGift",
    "StoryArea",
    "InputStoryAreaTypeLocation",
    "InputStoryAreaTypeFoundVenue",
    "InputStoryAreaTypePreviousVenue",
    "InputStoryAreaTypeSuggestedReaction",
    "InputStoryAreaTypeMessage",
    "InputStoryAreaTypeLink",
    "InputStoryAreaTypeWeather",
    "InputStoryAreaTypeUpgradedGift",
    "InputStoryArea",
    "InputStoryAreas",
    "StoryVideo",
    "StoryContentPhoto",
    "StoryContentVideo",
    "StoryContentUnsupported",
    "InputStoryContentPhoto",
    "InputStoryContentVideo",
    "StoryListMain",
    "StoryListArchive",
    "StoryOriginPublicStory",
    "StoryOriginHiddenUser",
    "StoryRepostInfo",
    "StoryInteractionInfo",
    "Story",
    "Stories",
    "FoundStories",
    "StoryAlbum",
    "StoryAlbums",
    "StoryFullId",
    "StoryInfo",
    "ChatActiveStories",
    "StoryInteractionTypeView",
    "StoryInteractionTypeForward",
    "StoryInteractionTypeRepost",
    "StoryInteraction",
    "StoryInteractions",
    "QuickReplyMessage",
    "QuickReplyMessages",
    "QuickReplyShortcut",
    "PublicForwardMessage",
    "PublicForwardStory",
    "PublicForwards",
    "BotMediaPreview",
    "BotMediaPreviews",
    "BotMediaPreviewInfo",
    "ChatBoostLevelFeatures",
    "ChatBoostFeatures",
    "ChatBoostSourceGiftCode",
    "ChatBoostSourceGiveaway",
    "ChatBoostSourcePremium",
    "PrepaidGiveaway",
    "ChatBoostStatus",
    "ChatBoost",
    "FoundChatBoosts",
    "ChatBoostSlot",
    "ChatBoostSlots",
    "ResendCodeReasonUserRequest",
    "ResendCodeReasonVerificationFailed",
    "CallDiscardReasonEmpty",
    "CallDiscardReasonMissed",
    "CallDiscardReasonDeclined",
    "CallDiscardReasonDisconnected",
    "CallDiscardReasonHungUp",
    "CallDiscardReasonUpgradeToGroupCall",
    "CallProtocol",
    "CallServerTypeTelegramReflector",
    "CallServerTypeWebrtc",
    "CallServer",
    "CallId",
    "GroupCallId",
    "CallStatePending",
    "CallStateExchangingKeys",
    "CallStateReady",
    "CallStateHangingUp",
    "CallStateDiscarded",
    "CallStateError",
    "GroupCallJoinParameters",
    "GroupCallVideoQualityThumbnail",
    "GroupCallVideoQualityMedium",
    "GroupCallVideoQualityFull",
    "VideoChatStream",
    "VideoChatStreams",
    "RtmpUrl",
    "GroupCallRecentSpeaker",
    "GroupCall",
    "GroupCallVideoSourceGroup",
    "GroupCallParticipantVideoInfo",
    "GroupCallParticipant",
    "GroupCallParticipants",
    "GroupCallInfo",
    "InviteGroupCallParticipantResultUserPrivacyRestricted",
    "InviteGroupCallParticipantResultUserAlreadyParticipant",
    "InviteGroupCallParticipantResultUserWasBanned",
    "InviteGroupCallParticipantResultSuccess",
    "GroupCallDataChannelMain",
    "GroupCallDataChannelScreenSharing",
    "InputGroupCallLink",
    "InputGroupCallMessage",
    "CallProblemEcho",
    "CallProblemNoise",
    "CallProblemInterruptions",
    "CallProblemDistortedSpeech",
    "CallProblemSilentLocal",
    "CallProblemSilentRemote",
    "CallProblemDropped",
    "CallProblemDistortedVideo",
    "CallProblemPixelatedVideo",
    "Call",
    "FirebaseAuthenticationSettingsAndroid",
    "FirebaseAuthenticationSettingsIos",
    "PhoneNumberAuthenticationSettings",
    "AddedReaction",
    "AddedReactions",
    "AvailableReaction",
    "AvailableReactions",
    "EmojiReaction",
    "ReactionUnavailabilityReasonAnonymousAdministrator",
    "ReactionUnavailabilityReasonGuest",
    "Animations",
    "DiceStickersRegular",
    "DiceStickersSlotMachine",
    "ImportedContacts",
    "SpeechRecognitionResultPending",
    "SpeechRecognitionResultText",
    "SpeechRecognitionResultError",
    "BusinessConnection",
    "AttachmentMenuBotColor",
    "AttachmentMenuBot",
    "SentWebAppMessage",
    "BotWriteAccessAllowReasonConnectedWebsite",
    "BotWriteAccessAllowReasonAddedToAttachmentMenu",
    "BotWriteAccessAllowReasonLaunchedWebApp",
    "BotWriteAccessAllowReasonAcceptedRequest",
    "HttpUrl",
    "UserLink",
    "TargetChatTypes",
    "TargetChatCurrent",
    "TargetChatChosen",
    "TargetChatInternalLink",
    "InputInlineQueryResultAnimation",
    "InputInlineQueryResultArticle",
    "InputInlineQueryResultAudio",
    "InputInlineQueryResultContact",
    "InputInlineQueryResultDocument",
    "InputInlineQueryResultGame",
    "InputInlineQueryResultLocation",
    "InputInlineQueryResultPhoto",
    "InputInlineQueryResultSticker",
    "InputInlineQueryResultVenue",
    "InputInlineQueryResultVideo",
    "InputInlineQueryResultVoiceNote",
    "InlineQueryResultArticle",
    "InlineQueryResultContact",
    "InlineQueryResultLocation",
    "InlineQueryResultVenue",
    "InlineQueryResultGame",
    "InlineQueryResultAnimation",
    "InlineQueryResultAudio",
    "InlineQueryResultDocument",
    "InlineQueryResultPhoto",
    "InlineQueryResultSticker",
    "InlineQueryResultVideo",
    "InlineQueryResultVoiceNote",
    "InlineQueryResultsButtonTypeStartBot",
    "InlineQueryResultsButtonTypeWebApp",
    "InlineQueryResultsButton",
    "InlineQueryResults",
    "PreparedInlineMessageId",
    "PreparedInlineMessage",
    "CallbackQueryPayloadData",
    "CallbackQueryPayloadDataWithPassword",
    "CallbackQueryPayloadGame",
    "CallbackQueryAnswer",
    "CustomRequestResult",
    "GameHighScore",
    "GameHighScores",
    "ChatEventMessageEdited",
    "ChatEventMessageDeleted",
    "ChatEventMessagePinned",
    "ChatEventMessageUnpinned",
    "ChatEventPollStopped",
    "ChatEventMemberJoined",
    "ChatEventMemberJoinedByInviteLink",
    "ChatEventMemberJoinedByRequest",
    "ChatEventMemberInvited",
    "ChatEventMemberLeft",
    "ChatEventMemberPromoted",
    "ChatEventMemberRestricted",
    "ChatEventMemberSubscriptionExtended",
    "ChatEventAvailableReactionsChanged",
    "ChatEventBackgroundChanged",
    "ChatEventDescriptionChanged",
    "ChatEventEmojiStatusChanged",
    "ChatEventLinkedChatChanged",
    "ChatEventLocationChanged",
    "ChatEventMessageAutoDeleteTimeChanged",
    "ChatEventPermissionsChanged",
    "ChatEventPhotoChanged",
    "ChatEventSlowModeDelayChanged",
    "ChatEventStickerSetChanged",
    "ChatEventCustomEmojiStickerSetChanged",
    "ChatEventTitleChanged",
    "ChatEventUsernameChanged",
    "ChatEventActiveUsernamesChanged",
    "ChatEventAccentColorChanged",
    "ChatEventProfileAccentColorChanged",
    "ChatEventHasProtectedContentToggled",
    "ChatEventInvitesToggled",
    "ChatEventIsAllHistoryAvailableToggled",
    "ChatEventHasAggressiveAntiSpamEnabledToggled",
    "ChatEventSignMessagesToggled",
    "ChatEventShowMessageSenderToggled",
    "ChatEventAutomaticTranslationToggled",
    "ChatEventInviteLinkEdited",
    "ChatEventInviteLinkRevoked",
    "ChatEventInviteLinkDeleted",
    "ChatEventVideoChatCreated",
    "ChatEventVideoChatEnded",
    "ChatEventVideoChatMuteNewParticipantsToggled",
    "ChatEventVideoChatParticipantIsMutedToggled",
    "ChatEventVideoChatParticipantVolumeLevelChanged",
    "ChatEventIsForumToggled",
    "ChatEventForumTopicCreated",
    "ChatEventForumTopicEdited",
    "ChatEventForumTopicToggleIsClosed",
    "ChatEventForumTopicToggleIsHidden",
    "ChatEventForumTopicDeleted",
    "ChatEventForumTopicPinned",
    "ChatEvent",
    "ChatEvents",
    "ChatEventLogFilters",
    "LanguagePackStringValueOrdinary",
    "LanguagePackStringValuePluralized",
    "LanguagePackStringValueDeleted",
    "LanguagePackString",
    "LanguagePackStrings",
    "LanguagePackInfo",
    "LocalizationTargetInfo",
    "PremiumLimitTypeSupergroupCount",
    "PremiumLimitTypePinnedChatCount",
    "PremiumLimitTypeCreatedPublicChatCount",
    "PremiumLimitTypeSavedAnimationCount",
    "PremiumLimitTypeFavoriteStickerCount",
    "PremiumLimitTypeChatFolderCount",
    "PremiumLimitTypeChatFolderChosenChatCount",
    "PremiumLimitTypePinnedArchivedChatCount",
    "PremiumLimitTypePinnedSavedMessagesTopicCount",
    "PremiumLimitTypeCaptionLength",
    "PremiumLimitTypeBioLength",
    "PremiumLimitTypeChatFolderInviteLinkCount",
    "PremiumLimitTypeShareableChatFolderCount",
    "PremiumLimitTypeActiveStoryCount",
    "PremiumLimitTypeWeeklyPostedStoryCount",
    "PremiumLimitTypeMonthlyPostedStoryCount",
    "PremiumLimitTypeStoryCaptionLength",
    "PremiumLimitTypeStorySuggestedReactionAreaCount",
    "PremiumLimitTypeSimilarChatCount",
    "PremiumFeatureIncreasedLimits",
    "PremiumFeatureIncreasedUploadFileSize",
    "PremiumFeatureImprovedDownloadSpeed",
    "PremiumFeatureVoiceRecognition",
    "PremiumFeatureDisabledAds",
    "PremiumFeatureUniqueReactions",
    "PremiumFeatureUniqueStickers",
    "PremiumFeatureCustomEmoji",
    "PremiumFeatureAdvancedChatManagement",
    "PremiumFeatureProfileBadge",
    "PremiumFeatureEmojiStatus",
    "PremiumFeatureAnimatedProfilePhoto",
    "PremiumFeatureForumTopicIcon",
    "PremiumFeatureAppIcons",
    "PremiumFeatureRealTimeChatTranslation",
    "PremiumFeatureUpgradedStories",
    "PremiumFeatureChatBoost",
    "PremiumFeatureAccentColor",
    "PremiumFeatureBackgroundForBoth",
    "PremiumFeatureSavedMessagesTags",
    "PremiumFeatureMessagePrivacy",
    "PremiumFeatureLastSeenTimes",
    "PremiumFeatureBusiness",
    "PremiumFeatureMessageEffects",
    "PremiumFeatureChecklists",
    "BusinessFeatureLocation",
    "BusinessFeatureOpeningHours",
    "BusinessFeatureQuickReplies",
    "BusinessFeatureGreetingMessage",
    "BusinessFeatureAwayMessage",
    "BusinessFeatureAccountLinks",
    "BusinessFeatureStartPage",
    "BusinessFeatureBots",
    "BusinessFeatureEmojiStatus",
    "BusinessFeatureChatFolderTags",
    "BusinessFeatureUpgradedStories",
    "PremiumStoryFeaturePriorityOrder",
    "PremiumStoryFeatureStealthMode",
    "PremiumStoryFeaturePermanentViewsHistory",
    "PremiumStoryFeatureCustomExpirationDuration",
    "PremiumStoryFeatureSaveStories",
    "PremiumStoryFeatureLinksAndFormatting",
    "PremiumStoryFeatureVideoQuality",
    "PremiumLimit",
    "PremiumFeatures",
    "BusinessFeatures",
    "PremiumSourceLimitExceeded",
    "PremiumSourceFeature",
    "PremiumSourceBusinessFeature",
    "PremiumSourceStoryFeature",
    "PremiumSourceLink",
    "PremiumSourceSettings",
    "PremiumFeaturePromotionAnimation",
    "BusinessFeaturePromotionAnimation",
    "PremiumState",
    "StorePaymentPurposePremiumSubscription",
    "StorePaymentPurposePremiumGift",
    "StorePaymentPurposePremiumGiftCodes",
    "StorePaymentPurposePremiumGiveaway",
    "StorePaymentPurposeStarGiveaway",
    "StorePaymentPurposeStars",
    "StorePaymentPurposeGiftedStars",
    "StoreTransactionAppStore",
    "StoreTransactionGooglePlay",
    "TelegramPaymentPurposePremiumGift",
    "TelegramPaymentPurposePremiumGiftCodes",
    "TelegramPaymentPurposePremiumGiveaway",
    "TelegramPaymentPurposeStars",
    "TelegramPaymentPurposeGiftedStars",
    "TelegramPaymentPurposeStarGiveaway",
    "TelegramPaymentPurposeJoinChat",
    "DeviceTokenFirebaseCloudMessaging",
    "DeviceTokenApplePush",
    "DeviceTokenApplePushVoIP",
    "DeviceTokenWindowsPush",
    "DeviceTokenMicrosoftPush",
    "DeviceTokenMicrosoftPushVoIP",
    "DeviceTokenWebPush",
    "DeviceTokenSimplePush",
    "DeviceTokenUbuntuPush",
    "DeviceTokenBlackBerryPush",
    "DeviceTokenTizenPush",
    "DeviceTokenHuaweiPush",
    "PushReceiverId",
    "BackgroundFillSolid",
    "BackgroundFillGradient",
    "BackgroundFillFreeformGradient",
    "BackgroundTypeWallpaper",
    "BackgroundTypePattern",
    "BackgroundTypeFill",
    "BackgroundTypeChatTheme",
    "InputBackgroundLocal",
    "InputBackgroundRemote",
    "InputBackgroundPrevious",
    "EmojiChatTheme",
    "GiftChatTheme",
    "GiftChatThemes",
    "ChatThemeEmoji",
    "ChatThemeGift",
    "InputChatThemeEmoji",
    "InputChatThemeGift",
    "TimeZone",
    "TimeZones",
    "Hashtags",
    "CanPostStoryResultOk",
    "CanPostStoryResultPremiumNeeded",
    "CanPostStoryResultBoostNeeded",
    "CanPostStoryResultActiveStoryLimitExceeded",
    "CanPostStoryResultWeeklyLimitExceeded",
    "CanPostStoryResultMonthlyLimitExceeded",
    "CanTransferOwnershipResultOk",
    "CanTransferOwnershipResultPasswordNeeded",
    "CanTransferOwnershipResultPasswordTooFresh",
    "CanTransferOwnershipResultSessionTooFresh",
    "CheckChatUsernameResultOk",
    "CheckChatUsernameResultUsernameInvalid",
    "CheckChatUsernameResultUsernameOccupied",
    "CheckChatUsernameResultUsernamePurchasable",
    "CheckChatUsernameResultPublicChatsTooMany",
    "CheckChatUsernameResultPublicGroupsUnavailable",
    "CheckStickerSetNameResultOk",
    "CheckStickerSetNameResultNameInvalid",
    "CheckStickerSetNameResultNameOccupied",
    "ResetPasswordResultOk",
    "ResetPasswordResultPending",
    "ResetPasswordResultDeclined",
    "MessageFileTypePrivate",
    "MessageFileTypeGroup",
    "MessageFileTypeUnknown",
    "PushMessageContentHidden",
    "PushMessageContentAnimation",
    "PushMessageContentAudio",
    "PushMessageContentContact",
    "PushMessageContentContactRegistered",
    "PushMessageContentDocument",
    "PushMessageContentGame",
    "PushMessageContentGameScore",
    "PushMessageContentInvoice",
    "PushMessageContentLocation",
    "PushMessageContentPaidMedia",
    "PushMessageContentPhoto",
    "PushMessageContentPoll",
    "PushMessageContentPremiumGiftCode",
    "PushMessageContentGiveaway",
    "PushMessageContentGift",
    "PushMessageContentUpgradedGift",
    "PushMessageContentScreenshotTaken",
    "PushMessageContentSticker",
    "PushMessageContentStory",
    "PushMessageContentText",
    "PushMessageContentChecklist",
    "PushMessageContentVideo",
    "PushMessageContentVideoNote",
    "PushMessageContentVoiceNote",
    "PushMessageContentBasicGroupChatCreate",
    "PushMessageContentVideoChatStarted",
    "PushMessageContentVideoChatEnded",
    "PushMessageContentInviteVideoChatParticipants",
    "PushMessageContentChatAddMembers",
    "PushMessageContentChatChangePhoto",
    "PushMessageContentChatChangeTitle",
    "PushMessageContentChatSetBackground",
    "PushMessageContentChatSetTheme",
    "PushMessageContentChatDeleteMember",
    "PushMessageContentChatJoinByLink",
    "PushMessageContentChatJoinByRequest",
    "PushMessageContentRecurringPayment",
    "PushMessageContentSuggestProfilePhoto",
    "PushMessageContentProximityAlertTriggered",
    "PushMessageContentChecklistTasksAdded",
    "PushMessageContentChecklistTasksDone",
    "PushMessageContentMessageForwards",
    "PushMessageContentMediaAlbum",
    "NotificationTypeNewMessage",
    "NotificationTypeNewSecretChat",
    "NotificationTypeNewCall",
    "NotificationTypeNewPushMessage",
    "NotificationGroupTypeMessages",
    "NotificationGroupTypeMentions",
    "NotificationGroupTypeSecretChat",
    "NotificationGroupTypeCalls",
    "NotificationSound",
    "NotificationSounds",
    "Notification",
    "NotificationGroup",
    "OptionValueBoolean",
    "OptionValueEmpty",
    "OptionValueInteger",
    "OptionValueString",
    "JsonObjectMember",
    "JsonValueNull",
    "JsonValueBoolean",
    "JsonValueNumber",
    "JsonValueString",
    "JsonValueArray",
    "JsonValueObject",
    "StoryPrivacySettingsEveryone",
    "StoryPrivacySettingsContacts",
    "StoryPrivacySettingsCloseFriends",
    "StoryPrivacySettingsSelectedUsers",
    "UserPrivacySettingRuleAllowAll",
    "UserPrivacySettingRuleAllowContacts",
    "UserPrivacySettingRuleAllowBots",
    "UserPrivacySettingRuleAllowPremiumUsers",
    "UserPrivacySettingRuleAllowUsers",
    "UserPrivacySettingRuleAllowChatMembers",
    "UserPrivacySettingRuleRestrictAll",
    "UserPrivacySettingRuleRestrictContacts",
    "UserPrivacySettingRuleRestrictBots",
    "UserPrivacySettingRuleRestrictUsers",
    "UserPrivacySettingRuleRestrictChatMembers",
    "UserPrivacySettingRules",
    "UserPrivacySettingShowStatus",
    "UserPrivacySettingShowProfilePhoto",
    "UserPrivacySettingShowLinkInForwardedMessages",
    "UserPrivacySettingShowPhoneNumber",
    "UserPrivacySettingShowBio",
    "UserPrivacySettingShowBirthdate",
    "UserPrivacySettingAllowChatInvites",
    "UserPrivacySettingAllowCalls",
    "UserPrivacySettingAllowPeerToPeerCalls",
    "UserPrivacySettingAllowFindingByPhoneNumber",
    "UserPrivacySettingAllowPrivateVoiceAndVideoNoteMessages",
    "UserPrivacySettingAutosaveGifts",
    "UserPrivacySettingAllowUnpaidMessages",
    "ReadDatePrivacySettings",
    "NewChatPrivacySettings",
    "CanSendMessageToUserResultOk",
    "CanSendMessageToUserResultUserHasPaidMessages",
    "CanSendMessageToUserResultUserIsDeleted",
    "CanSendMessageToUserResultUserRestrictsNewChats",
    "AccountTtl",
    "MessageAutoDeleteTime",
    "SessionTypeAndroid",
    "SessionTypeApple",
    "SessionTypeBrave",
    "SessionTypeChrome",
    "SessionTypeEdge",
    "SessionTypeFirefox",
    "SessionTypeIpad",
    "SessionTypeIphone",
    "SessionTypeLinux",
    "SessionTypeMac",
    "SessionTypeOpera",
    "SessionTypeSafari",
    "SessionTypeUbuntu",
    "SessionTypeUnknown",
    "SessionTypeVivaldi",
    "SessionTypeWindows",
    "SessionTypeXbox",
    "Session",
    "Sessions",
    "UnconfirmedSession",
    "ConnectedWebsite",
    "ConnectedWebsites",
    "ReportReasonSpam",
    "ReportReasonViolence",
    "ReportReasonPornography",
    "ReportReasonChildAbuse",
    "ReportReasonCopyright",
    "ReportReasonUnrelatedLocation",
    "ReportReasonFake",
    "ReportReasonIllegalDrugs",
    "ReportReasonPersonalDetails",
    "ReportReasonCustom",
    "ReportChatResultOk",
    "ReportChatResultOptionRequired",
    "ReportChatResultTextRequired",
    "ReportChatResultMessagesRequired",
    "ReportStoryResultOk",
    "ReportStoryResultOptionRequired",
    "ReportStoryResultTextRequired",
    "InternalLinkTypeActiveSessions",
    "InternalLinkTypeAttachmentMenuBot",
    "InternalLinkTypeAuthenticationCode",
    "InternalLinkTypeBackground",
    "InternalLinkTypeBotAddToChannel",
    "InternalLinkTypeBotStart",
    "InternalLinkTypeBotStartInGroup",
    "InternalLinkTypeBusinessChat",
    "InternalLinkTypeBuyStars",
    "InternalLinkTypeChangePhoneNumber",
    "InternalLinkTypeChatAffiliateProgram",
    "InternalLinkTypeChatBoost",
    "InternalLinkTypeChatFolderInvite",
    "InternalLinkTypeChatFolderSettings",
    "InternalLinkTypeChatInvite",
    "InternalLinkTypeDefaultMessageAutoDeleteTimerSettings",
    "InternalLinkTypeDirectMessagesChat",
    "InternalLinkTypeEditProfileSettings",
    "InternalLinkTypeGame",
    "InternalLinkTypeGiftCollection",
    "InternalLinkTypeGroupCall",
    "InternalLinkTypeInstantView",
    "InternalLinkTypeInvoice",
    "InternalLinkTypeLanguagePack",
    "InternalLinkTypeLanguageSettings",
    "InternalLinkTypeMainWebApp",
    "InternalLinkTypeMessage",
    "InternalLinkTypeMessageDraft",
    "InternalLinkTypeMyStars",
    "InternalLinkTypeMyToncoins",
    "InternalLinkTypePassportDataRequest",
    "InternalLinkTypePhoneNumberConfirmation",
    "InternalLinkTypePremiumFeatures",
    "InternalLinkTypePremiumGift",
    "InternalLinkTypePremiumGiftCode",
    "InternalLinkTypePrivacyAndSecuritySettings",
    "InternalLinkTypeProxy",
    "InternalLinkTypePublicChat",
    "InternalLinkTypeQrCodeAuthentication",
    "InternalLinkTypeRestorePurchases",
    "InternalLinkTypeSettings",
    "InternalLinkTypeStickerSet",
    "InternalLinkTypeStory",
    "InternalLinkTypeStoryAlbum",
    "InternalLinkTypeTheme",
    "InternalLinkTypeThemeSettings",
    "InternalLinkTypeUnknownDeepLink",
    "InternalLinkTypeUnsupportedProxy",
    "InternalLinkTypeUpgradedGift",
    "InternalLinkTypeUserPhoneNumber",
    "InternalLinkTypeUserToken",
    "InternalLinkTypeVideoChat",
    "InternalLinkTypeWebApp",
    "MessageLink",
    "MessageLinkInfo",
    "ChatBoostLink",
    "ChatBoostLinkInfo",
    "BlockListMain",
    "BlockListStories",
    "FileTypeNone",
    "FileTypeAnimation",
    "FileTypeAudio",
    "FileTypeDocument",
    "FileTypeNotificationSound",
    "FileTypePhoto",
    "FileTypePhotoStory",
    "FileTypeProfilePhoto",
    "FileTypeSecret",
    "FileTypeSecretThumbnail",
    "FileTypeSecure",
    "FileTypeSelfDestructingPhoto",
    "FileTypeSelfDestructingVideo",
    "FileTypeSelfDestructingVideoNote",
    "FileTypeSelfDestructingVoiceNote",
    "FileTypeSticker",
    "FileTypeThumbnail",
    "FileTypeUnknown",
    "FileTypeVideo",
    "FileTypeVideoNote",
    "FileTypeVideoStory",
    "FileTypeVoiceNote",
    "FileTypeWallpaper",
    "StorageStatisticsByFileType",
    "StorageStatisticsByChat",
    "StorageStatistics",
    "StorageStatisticsFast",
    "DatabaseStatistics",
    "NetworkTypeNone",
    "NetworkTypeMobile",
    "NetworkTypeMobileRoaming",
    "NetworkTypeWiFi",
    "NetworkTypeOther",
    "NetworkStatisticsEntryFile",
    "NetworkStatisticsEntryCall",
    "NetworkStatistics",
    "AutoDownloadSettings",
    "AutoDownloadSettingsPresets",
    "AutosaveSettingsScopePrivateChats",
    "AutosaveSettingsScopeGroupChats",
    "AutosaveSettingsScopeChannelChats",
    "AutosaveSettingsScopeChat",
    "ScopeAutosaveSettings",
    "AutosaveSettingsException",
    "AutosaveSettings",
    "ConnectionStateWaitingForNetwork",
    "ConnectionStateConnectingToProxy",
    "ConnectionStateConnecting",
    "ConnectionStateUpdating",
    "ConnectionStateReady",
    "AgeVerificationParameters",
    "TopChatCategoryUsers",
    "TopChatCategoryBots",
    "TopChatCategoryGroups",
    "TopChatCategoryChannels",
    "TopChatCategoryInlineBots",
    "TopChatCategoryWebAppBots",
    "TopChatCategoryCalls",
    "TopChatCategoryForwardChats",
    "FoundPosition",
    "FoundPositions",
    "TMeUrlTypeUser",
    "TMeUrlTypeSupergroup",
    "TMeUrlTypeChatInvite",
    "TMeUrlTypeStickerSet",
    "TMeUrl",
    "TMeUrls",
    "SuggestedActionEnableArchiveAndMuteNewChats",
    "SuggestedActionCheckPassword",
    "SuggestedActionCheckPhoneNumber",
    "SuggestedActionViewChecksHint",
    "SuggestedActionConvertToBroadcastGroup",
    "SuggestedActionSetPassword",
    "SuggestedActionUpgradePremium",
    "SuggestedActionRestorePremium",
    "SuggestedActionSubscribeToAnnualPremium",
    "SuggestedActionGiftPremiumForChristmas",
    "SuggestedActionSetBirthdate",
    "SuggestedActionSetProfilePhoto",
    "SuggestedActionExtendPremium",
    "SuggestedActionExtendStarSubscriptions",
    "SuggestedActionCustom",
    "Count",
    "Text",
    "Data",
    "Seconds",
    "FileDownloadedPrefixSize",
    "StarCount",
    "DeepLinkInfo",
    "TextParseModeMarkdown",
    "TextParseModeHTML",
    "ProxyTypeSocks5",
    "ProxyTypeHttp",
    "ProxyTypeMtproto",
    "Proxy",
    "Proxies",
    "InputSticker",
    "DateRange",
    "StatisticalValue",
    "StatisticalGraphData",
    "StatisticalGraphAsync",
    "StatisticalGraphError",
    "ChatStatisticsObjectTypeMessage",
    "ChatStatisticsObjectTypeStory",
    "ChatStatisticsInteractionInfo",
    "ChatStatisticsMessageSenderInfo",
    "ChatStatisticsAdministratorActionsInfo",
    "ChatStatisticsInviterInfo",
    "ChatStatisticsSupergroup",
    "ChatStatisticsChannel",
    "ChatRevenueAmount",
    "ChatRevenueStatistics",
    "MessageStatistics",
    "StoryStatistics",
    "RevenueWithdrawalStatePending",
    "RevenueWithdrawalStateSucceeded",
    "RevenueWithdrawalStateFailed",
    "ChatRevenueTransactionTypeUnsupported",
    "ChatRevenueTransactionTypeSponsoredMessageEarnings",
    "ChatRevenueTransactionTypeSuggestedPostEarnings",
    "ChatRevenueTransactionTypeFragmentWithdrawal",
    "ChatRevenueTransactionTypeFragmentRefund",
    "ChatRevenueTransaction",
    "ChatRevenueTransactions",
    "StarRevenueStatus",
    "StarRevenueStatistics",
    "TonRevenueStatus",
    "TonRevenueStatistics",
    "Point",
    "VectorPathCommandLine",
    "VectorPathCommandCubicBezierCurve",
    "BotCommandScopeDefault",
    "BotCommandScopeAllPrivateChats",
    "BotCommandScopeAllGroupChats",
    "BotCommandScopeAllChatAdministrators",
    "BotCommandScopeChat",
    "BotCommandScopeChatAdministrators",
    "BotCommandScopeChatMember",
    "PhoneNumberCodeTypeChange",
    "PhoneNumberCodeTypeVerify",
    "PhoneNumberCodeTypeConfirmOwnership",
    "LogStreamDefault",
    "LogStreamFile",
    "LogStreamEmpty",
    "LogVerbosityLevel",
    "LogTags",
    "UserSupportInfo",
    "TestInt",
    "TestString",
    "TestBytes",
    "TestVectorInt",
    "TestVectorIntObject",
    "TestVectorString",
    "TestVectorStringObject",
    "UpdateAuthorizationState",
    "UpdateNewMessage",
    "UpdateMessageSendAcknowledged",
    "UpdateMessageSendSucceeded",
    "UpdateMessageSendFailed",
    "UpdateMessageContent",
    "UpdateMessageEdited",
    "UpdateMessageIsPinned",
    "UpdateMessageInteractionInfo",
    "UpdateMessageContentOpened",
    "UpdateMessageMentionRead",
    "UpdateMessageUnreadReactions",
    "UpdateMessageFactCheck",
    "UpdateMessageSuggestedPostInfo",
    "UpdateMessageLiveLocationViewed",
    "UpdateVideoPublished",
    "UpdateNewChat",
    "UpdateChatTitle",
    "UpdateChatPhoto",
    "UpdateChatAccentColors",
    "UpdateChatPermissions",
    "UpdateChatLastMessage",
    "UpdateChatPosition",
    "UpdateChatAddedToList",
    "UpdateChatRemovedFromList",
    "UpdateChatReadInbox",
    "UpdateChatReadOutbox",
    "UpdateChatActionBar",
    "UpdateChatBusinessBotManageBar",
    "UpdateChatAvailableReactions",
    "UpdateChatDraftMessage",
    "UpdateChatEmojiStatus",
    "UpdateChatMessageSender",
    "UpdateChatMessageAutoDeleteTime",
    "UpdateChatNotificationSettings",
    "UpdateChatPendingJoinRequests",
    "UpdateChatReplyMarkup",
    "UpdateChatBackground",
    "UpdateChatTheme",
    "UpdateChatUnreadMentionCount",
    "UpdateChatUnreadReactionCount",
    "UpdateChatVideoChat",
    "UpdateChatDefaultDisableNotification",
    "UpdateChatHasProtectedContent",
    "UpdateChatIsTranslatable",
    "UpdateChatIsMarkedAsUnread",
    "UpdateChatViewAsTopics",
    "UpdateChatBlockList",
    "UpdateChatHasScheduledMessages",
    "UpdateChatFolders",
    "UpdateChatOnlineMemberCount",
    "UpdateSavedMessagesTopic",
    "UpdateSavedMessagesTopicCount",
    "UpdateDirectMessagesChatTopic",
    "UpdateTopicMessageCount",
    "UpdateQuickReplyShortcut",
    "UpdateQuickReplyShortcutDeleted",
    "UpdateQuickReplyShortcuts",
    "UpdateQuickReplyShortcutMessages",
    "UpdateForumTopicInfo",
    "UpdateForumTopic",
    "UpdateScopeNotificationSettings",
    "UpdateReactionNotificationSettings",
    "UpdateNotification",
    "UpdateNotificationGroup",
    "UpdateActiveNotifications",
    "UpdateHavePendingNotifications",
    "UpdateDeleteMessages",
    "UpdateChatAction",
    "UpdateUserStatus",
    "UpdateUser",
    "UpdateBasicGroup",
    "UpdateSupergroup",
    "UpdateSecretChat",
    "UpdateUserFullInfo",
    "UpdateBasicGroupFullInfo",
    "UpdateSupergroupFullInfo",
    "UpdateServiceNotification",
    "UpdateFile",
    "UpdateFileGenerationStart",
    "UpdateFileGenerationStop",
    "UpdateFileDownloads",
    "UpdateFileAddedToDownloads",
    "UpdateFileDownload",
    "UpdateFileRemovedFromDownloads",
    "UpdateApplicationVerificationRequired",
    "UpdateApplicationRecaptchaVerificationRequired",
    "UpdateCall",
    "UpdateGroupCall",
    "UpdateGroupCallParticipant",
    "UpdateGroupCallParticipants",
    "UpdateGroupCallVerificationState",
    "UpdateNewCallSignalingData",
    "UpdateUserPrivacySettingRules",
    "UpdateUnreadMessageCount",
    "UpdateUnreadChatCount",
    "UpdateStory",
    "UpdateStoryDeleted",
    "UpdateStoryPostSucceeded",
    "UpdateStoryPostFailed",
    "UpdateChatActiveStories",
    "UpdateStoryListChatCount",
    "UpdateStoryStealthMode",
    "UpdateOption",
    "UpdateStickerSet",
    "UpdateInstalledStickerSets",
    "UpdateTrendingStickerSets",
    "UpdateRecentStickers",
    "UpdateFavoriteStickers",
    "UpdateSavedAnimations",
    "UpdateSavedNotificationSounds",
    "UpdateDefaultBackground",
    "UpdateEmojiChatThemes",
    "UpdateAccentColors",
    "UpdateProfileAccentColors",
    "UpdateLanguagePackStrings",
    "UpdateConnectionState",
    "UpdateFreezeState",
    "UpdateAgeVerificationParameters",
    "UpdateTermsOfService",
    "UpdateUnconfirmedSession",
    "UpdateAttachmentMenuBots",
    "UpdateWebAppMessageSent",
    "UpdateActiveEmojiReactions",
    "UpdateAvailableMessageEffects",
    "UpdateDefaultReactionType",
    "UpdateDefaultPaidReactionType",
    "UpdateSavedMessagesTags",
    "UpdateActiveLiveLocationMessages",
    "UpdateOwnedStarCount",
    "UpdateOwnedTonCount",
    "UpdateChatRevenueAmount",
    "UpdateStarRevenueStatus",
    "UpdateTonRevenueStatus",
    "UpdateSpeechRecognitionTrial",
    "UpdateDiceEmojis",
    "UpdateAnimatedEmojiMessageClicked",
    "UpdateAnimationSearchParameters",
    "UpdateSuggestedActions",
    "UpdateSpeedLimitNotification",
    "UpdateContactCloseBirthdays",
    "UpdateAutosaveSettings",
    "UpdateBusinessConnection",
    "UpdateNewBusinessMessage",
    "UpdateBusinessMessageEdited",
    "UpdateBusinessMessagesDeleted",
    "UpdateNewInlineQuery",
    "UpdateNewChosenInlineResult",
    "UpdateNewCallbackQuery",
    "UpdateNewInlineCallbackQuery",
    "UpdateNewBusinessCallbackQuery",
    "UpdateNewShippingQuery",
    "UpdateNewPreCheckoutQuery",
    "UpdateNewCustomEvent",
    "UpdateNewCustomQuery",
    "UpdatePoll",
    "UpdatePollAnswer",
    "UpdateChatMember",
    "UpdateNewChatJoinRequest",
    "UpdateChatBoost",
    "UpdateMessageReaction",
    "UpdateMessageReactions",
    "UpdatePaidMediaPurchased",
    "Updates",
]

from .td_types import (
    TlObject,
    AuthenticationCodeType,
    EmailAddressAuthentication,
    EmailAddressResetState,
    AuthorizationState,
    FirebaseDeviceVerificationParameters,
    InputFile,
    ThumbnailFormat,
    MaskPoint,
    StickerFormat,
    StickerType,
    StickerFullType,
    PollType,
    ProfileTab,
    UserType,
    BusinessAwayMessageSchedule,
    ChatPhotoStickerType,
    InputChatPhoto,
    GiftResalePrice,
    SuggestedPostPrice,
    SuggestedPostState,
    SuggestedPostRefundReason,
    StarSubscriptionType,
    AffiliateType,
    AffiliateProgramSortOrder,
    CanSendGiftResult,
    UpgradedGiftOrigin,
    UpgradedGiftAttributeId,
    GiftForResaleOrder,
    GiftResaleResult,
    SentGift,
    TransactionDirection,
    StarTransactionType,
    TonTransactionType,
    GiveawayParticipantStatus,
    GiveawayInfo,
    GiveawayPrize,
    EmojiStatusType,
    ChatMemberStatus,
    ChatMembersFilter,
    SupergroupMembersFilter,
    InviteLinkChatType,
    SecretChatState,
    MessageSender,
    MessageReadDate,
    MessageOrigin,
    ReactionType,
    PaidReactionType,
    MessageTopic,
    MessageEffectType,
    MessageSendingState,
    MessageReplyTo,
    InputMessageReplyTo,
    MessageSource,
    ReportSponsoredResult,
    NotificationSettingsScope,
    ReactionNotificationSource,
    ChatType,
    ChatList,
    ChatSource,
    ChatAvailableReactions,
    PublicChatType,
    ChatActionBar,
    KeyboardButtonType,
    InlineKeyboardButtonType,
    ReplyMarkup,
    LoginUrlInfo,
    WebAppOpenMode,
    SavedMessagesTopicType,
    BuiltInTheme,
    RichText,
    PageBlockHorizontalAlignment,
    PageBlockVerticalAlignment,
    PageBlock,
    LinkPreviewAlbumMedia,
    LinkPreviewType,
    CollectibleItemType,
    InputCredentials,
    PaymentProvider,
    PaymentFormType,
    PaymentReceiptType,
    InputInvoice,
    PaidMedia,
    PassportElementType,
    PassportElement,
    InputPassportElement,
    PassportElementErrorSource,
    InputPassportElementErrorSource,
    MessageContent,
    TextEntityType,
    InputPaidMediaType,
    MessageSchedulingState,
    MessageSelfDestructType,
    InputMessageContent,
    SearchMessagesFilter,
    SearchMessagesChatTypeFilter,
    ChatAction,
    UserStatus,
    EmojiCategorySource,
    EmojiCategoryType,
    StoryAreaType,
    InputStoryAreaType,
    StoryContent,
    InputStoryContent,
    StoryList,
    StoryOrigin,
    StoryInteractionType,
    PublicForward,
    ChatBoostSource,
    ResendCodeReason,
    CallDiscardReason,
    CallServerType,
    CallState,
    GroupCallVideoQuality,
    InviteGroupCallParticipantResult,
    GroupCallDataChannel,
    InputGroupCall,
    CallProblem,
    FirebaseAuthenticationSettings,
    ReactionUnavailabilityReason,
    DiceStickers,
    SpeechRecognitionResult,
    BotWriteAccessAllowReason,
    TargetChat,
    InputInlineQueryResult,
    InlineQueryResult,
    InlineQueryResultsButtonType,
    CallbackQueryPayload,
    ChatEventAction,
    LanguagePackStringValue,
    PremiumLimitType,
    PremiumFeature,
    BusinessFeature,
    PremiumStoryFeature,
    PremiumSource,
    StorePaymentPurpose,
    StoreTransaction,
    TelegramPaymentPurpose,
    DeviceToken,
    BackgroundFill,
    BackgroundType,
    InputBackground,
    ChatTheme,
    InputChatTheme,
    CanPostStoryResult,
    CanTransferOwnershipResult,
    CheckChatUsernameResult,
    CheckStickerSetNameResult,
    ResetPasswordResult,
    MessageFileType,
    PushMessageContent,
    NotificationType,
    NotificationGroupType,
    OptionValue,
    JsonValue,
    StoryPrivacySettings,
    UserPrivacySettingRule,
    UserPrivacySetting,
    CanSendMessageToUserResult,
    SessionType,
    ReportReason,
    ReportChatResult,
    ReportStoryResult,
    InternalLinkType,
    BlockList,
    FileType,
    NetworkType,
    NetworkStatisticsEntry,
    AutosaveSettingsScope,
    ConnectionState,
    TopChatCategory,
    TMeUrlType,
    SuggestedAction,
    TextParseMode,
    ProxyType,
    StatisticalGraph,
    ChatStatisticsObjectType,
    ChatStatistics,
    RevenueWithdrawalState,
    ChatRevenueTransactionType,
    VectorPathCommand,
    BotCommandScope,
    PhoneNumberCodeType,
    Update,
    LogStream,
    Error,
    Ok,
    AuthenticationCodeTypeTelegramMessage,
    AuthenticationCodeTypeSms,
    AuthenticationCodeTypeSmsWord,
    AuthenticationCodeTypeSmsPhrase,
    AuthenticationCodeTypeCall,
    AuthenticationCodeTypeFlashCall,
    AuthenticationCodeTypeMissedCall,
    AuthenticationCodeTypeFragment,
    AuthenticationCodeTypeFirebaseAndroid,
    AuthenticationCodeTypeFirebaseIos,
    AuthenticationCodeInfo,
    EmailAddressAuthenticationCodeInfo,
    EmailAddressAuthenticationCode,
    EmailAddressAuthenticationAppleId,
    EmailAddressAuthenticationGoogleId,
    EmailAddressResetStateAvailable,
    EmailAddressResetStatePending,
    TextEntity,
    TextEntities,
    FormattedText,
    TermsOfService,
    AuthorizationStateWaitTdlibParameters,
    AuthorizationStateWaitPhoneNumber,
    AuthorizationStateWaitPremiumPurchase,
    AuthorizationStateWaitEmailAddress,
    AuthorizationStateWaitEmailCode,
    AuthorizationStateWaitCode,
    AuthorizationStateWaitOtherDeviceConfirmation,
    AuthorizationStateWaitRegistration,
    AuthorizationStateWaitPassword,
    AuthorizationStateReady,
    AuthorizationStateLoggingOut,
    AuthorizationStateClosing,
    AuthorizationStateClosed,
    FirebaseDeviceVerificationParametersSafetyNet,
    FirebaseDeviceVerificationParametersPlayIntegrity,
    PasswordState,
    RecoveryEmailAddress,
    TemporaryPasswordState,
    LocalFile,
    RemoteFile,
    File,
    InputFileId,
    InputFileRemote,
    InputFileLocal,
    InputFileGenerated,
    PhotoSize,
    Minithumbnail,
    ThumbnailFormatJpeg,
    ThumbnailFormatGif,
    ThumbnailFormatMpeg4,
    ThumbnailFormatPng,
    ThumbnailFormatTgs,
    ThumbnailFormatWebm,
    ThumbnailFormatWebp,
    Thumbnail,
    MaskPointForehead,
    MaskPointEyes,
    MaskPointMouth,
    MaskPointChin,
    MaskPosition,
    StickerFormatWebp,
    StickerFormatTgs,
    StickerFormatWebm,
    StickerTypeRegular,
    StickerTypeMask,
    StickerTypeCustomEmoji,
    StickerFullTypeRegular,
    StickerFullTypeMask,
    StickerFullTypeCustomEmoji,
    ClosedVectorPath,
    Outline,
    PollOption,
    PollTypeRegular,
    PollTypeQuiz,
    ChecklistTask,
    InputChecklistTask,
    Checklist,
    InputChecklist,
    Animation,
    Audio,
    Audios,
    Document,
    Photo,
    Sticker,
    Video,
    VideoNote,
    VoiceNote,
    AnimatedEmoji,
    Contact,
    Location,
    Venue,
    Game,
    WebApp,
    Poll,
    AlternativeVideo,
    VideoStoryboard,
    Background,
    Backgrounds,
    ChatBackground,
    ProfilePhoto,
    ChatPhotoInfo,
    ProfileTabPosts,
    ProfileTabGifts,
    ProfileTabMedia,
    ProfileTabFiles,
    ProfileTabLinks,
    ProfileTabMusic,
    ProfileTabVoice,
    ProfileTabGifs,
    UserTypeRegular,
    UserTypeDeleted,
    UserTypeBot,
    UserTypeUnknown,
    BotCommand,
    BotCommands,
    BotMenuButton,
    BotVerificationParameters,
    BotVerification,
    VerificationStatus,
    ChatLocation,
    Birthdate,
    CloseBirthdayUser,
    BusinessAwayMessageScheduleAlways,
    BusinessAwayMessageScheduleOutsideOfOpeningHours,
    BusinessAwayMessageScheduleCustom,
    BusinessLocation,
    BusinessRecipients,
    BusinessAwayMessageSettings,
    BusinessGreetingMessageSettings,
    BusinessBotRights,
    BusinessConnectedBot,
    BusinessStartPage,
    InputBusinessStartPage,
    BusinessOpeningHoursInterval,
    BusinessOpeningHours,
    BusinessInfo,
    BusinessChatLink,
    BusinessChatLinks,
    InputBusinessChatLink,
    BusinessChatLinkInfo,
    ChatPhotoStickerTypeRegularOrMask,
    ChatPhotoStickerTypeCustomEmoji,
    ChatPhotoSticker,
    AnimatedChatPhoto,
    ChatPhoto,
    ChatPhotos,
    InputChatPhotoPrevious,
    InputChatPhotoStatic,
    InputChatPhotoAnimation,
    InputChatPhotoSticker,
    ChatPermissions,
    ChatAdministratorRights,
    GiftResalePriceStar,
    GiftResalePriceTon,
    SuggestedPostPriceStar,
    SuggestedPostPriceTon,
    SuggestedPostStatePending,
    SuggestedPostStateApproved,
    SuggestedPostStateDeclined,
    SuggestedPostInfo,
    InputSuggestedPostInfo,
    SuggestedPostRefundReasonPostDeleted,
    SuggestedPostRefundReasonPaymentRefunded,
    StarAmount,
    StarSubscriptionTypeChannel,
    StarSubscriptionTypeBot,
    StarSubscriptionPricing,
    StarSubscription,
    StarSubscriptions,
    AffiliateTypeCurrentUser,
    AffiliateTypeBot,
    AffiliateTypeChannel,
    AffiliateProgramSortOrderProfitability,
    AffiliateProgramSortOrderCreationDate,
    AffiliateProgramSortOrderRevenue,
    AffiliateProgramParameters,
    AffiliateProgramInfo,
    AffiliateInfo,
    FoundAffiliateProgram,
    FoundAffiliatePrograms,
    ConnectedAffiliateProgram,
    ConnectedAffiliatePrograms,
    ProductInfo,
    PremiumPaymentOption,
    PremiumStatePaymentOption,
    PremiumGiftPaymentOption,
    PremiumGiftPaymentOptions,
    PremiumGiveawayPaymentOption,
    PremiumGiveawayPaymentOptions,
    PremiumGiftCodeInfo,
    StarPaymentOption,
    StarPaymentOptions,
    StarGiveawayWinnerOption,
    StarGiveawayPaymentOption,
    StarGiveawayPaymentOptions,
    AcceptedGiftTypes,
    GiftSettings,
    GiftPurchaseLimits,
    GiftResaleParameters,
    GiftCollection,
    GiftCollections,
    CanSendGiftResultOk,
    CanSendGiftResultFail,
    UpgradedGiftOriginUpgrade,
    UpgradedGiftOriginTransfer,
    UpgradedGiftOriginResale,
    UpgradedGiftOriginPrepaidUpgrade,
    UpgradedGiftModel,
    UpgradedGiftSymbol,
    UpgradedGiftBackdropColors,
    UpgradedGiftBackdrop,
    UpgradedGiftOriginalDetails,
    Gift,
    UpgradedGift,
    UpgradedGiftValueInfo,
    UpgradeGiftResult,
    AvailableGift,
    AvailableGifts,
    UpgradedGiftAttributeIdModel,
    UpgradedGiftAttributeIdSymbol,
    UpgradedGiftAttributeIdBackdrop,
    UpgradedGiftModelCount,
    UpgradedGiftSymbolCount,
    UpgradedGiftBackdropCount,
    GiftForResaleOrderPrice,
    GiftForResaleOrderPriceChangeDate,
    GiftForResaleOrderNumber,
    GiftForResale,
    GiftsForResale,
    GiftResaleResultOk,
    GiftResaleResultPriceIncreased,
    SentGiftRegular,
    SentGiftUpgraded,
    ReceivedGift,
    ReceivedGifts,
    GiftUpgradePreview,
    TransactionDirectionIncoming,
    TransactionDirectionOutgoing,
    StarTransactionTypePremiumBotDeposit,
    StarTransactionTypeAppStoreDeposit,
    StarTransactionTypeGooglePlayDeposit,
    StarTransactionTypeFragmentDeposit,
    StarTransactionTypeUserDeposit,
    StarTransactionTypeGiveawayDeposit,
    StarTransactionTypeFragmentWithdrawal,
    StarTransactionTypeTelegramAdsWithdrawal,
    StarTransactionTypeTelegramApiUsage,
    StarTransactionTypeBotPaidMediaPurchase,
    StarTransactionTypeBotPaidMediaSale,
    StarTransactionTypeChannelPaidMediaPurchase,
    StarTransactionTypeChannelPaidMediaSale,
    StarTransactionTypeBotInvoicePurchase,
    StarTransactionTypeBotInvoiceSale,
    StarTransactionTypeBotSubscriptionPurchase,
    StarTransactionTypeBotSubscriptionSale,
    StarTransactionTypeChannelSubscriptionPurchase,
    StarTransactionTypeChannelSubscriptionSale,
    StarTransactionTypeGiftPurchase,
    StarTransactionTypeGiftTransfer,
    StarTransactionTypeGiftSale,
    StarTransactionTypeGiftUpgrade,
    StarTransactionTypeGiftUpgradePurchase,
    StarTransactionTypeUpgradedGiftPurchase,
    StarTransactionTypeUpgradedGiftSale,
    StarTransactionTypeChannelPaidReactionSend,
    StarTransactionTypeChannelPaidReactionReceive,
    StarTransactionTypeAffiliateProgramCommission,
    StarTransactionTypePaidMessageSend,
    StarTransactionTypePaidMessageReceive,
    StarTransactionTypeSuggestedPostPaymentSend,
    StarTransactionTypeSuggestedPostPaymentReceive,
    StarTransactionTypePremiumPurchase,
    StarTransactionTypeBusinessBotTransferSend,
    StarTransactionTypeBusinessBotTransferReceive,
    StarTransactionTypePublicPostSearch,
    StarTransactionTypeUnsupported,
    StarTransaction,
    StarTransactions,
    TonTransactionTypeFragmentDeposit,
    TonTransactionTypeSuggestedPostPayment,
    TonTransactionTypeUpgradedGiftPurchase,
    TonTransactionTypeUpgradedGiftSale,
    TonTransactionTypeUnsupported,
    TonTransaction,
    TonTransactions,
    GiveawayParticipantStatusEligible,
    GiveawayParticipantStatusParticipating,
    GiveawayParticipantStatusAlreadyWasMember,
    GiveawayParticipantStatusAdministrator,
    GiveawayParticipantStatusDisallowedCountry,
    GiveawayInfoOngoing,
    GiveawayInfoCompleted,
    GiveawayPrizePremium,
    GiveawayPrizeStars,
    AccentColor,
    ProfileAccentColors,
    ProfileAccentColor,
    UserRating,
    RestrictionInfo,
    EmojiStatusTypeCustomEmoji,
    EmojiStatusTypeUpgradedGift,
    EmojiStatus,
    EmojiStatuses,
    EmojiStatusCustomEmojis,
    Usernames,
    User,
    BotInfo,
    UserFullInfo,
    Users,
    FoundUsers,
    ChatAdministrator,
    ChatAdministrators,
    ChatMemberStatusCreator,
    ChatMemberStatusAdministrator,
    ChatMemberStatusMember,
    ChatMemberStatusRestricted,
    ChatMemberStatusLeft,
    ChatMemberStatusBanned,
    ChatMember,
    ChatMembers,
    ChatMembersFilterContacts,
    ChatMembersFilterAdministrators,
    ChatMembersFilterMembers,
    ChatMembersFilterMention,
    ChatMembersFilterRestricted,
    ChatMembersFilterBanned,
    ChatMembersFilterBots,
    SupergroupMembersFilterRecent,
    SupergroupMembersFilterContacts,
    SupergroupMembersFilterAdministrators,
    SupergroupMembersFilterSearch,
    SupergroupMembersFilterRestricted,
    SupergroupMembersFilterBanned,
    SupergroupMembersFilterMention,
    SupergroupMembersFilterBots,
    ChatInviteLink,
    ChatInviteLinks,
    ChatInviteLinkCount,
    ChatInviteLinkCounts,
    ChatInviteLinkMember,
    ChatInviteLinkMembers,
    InviteLinkChatTypeBasicGroup,
    InviteLinkChatTypeSupergroup,
    InviteLinkChatTypeChannel,
    ChatInviteLinkSubscriptionInfo,
    ChatInviteLinkInfo,
    ChatJoinRequest,
    ChatJoinRequests,
    ChatJoinRequestsInfo,
    BasicGroup,
    BasicGroupFullInfo,
    Supergroup,
    SupergroupFullInfo,
    SecretChatStatePending,
    SecretChatStateReady,
    SecretChatStateClosed,
    SecretChat,
    PublicPostSearchLimits,
    MessageSenderUser,
    MessageSenderChat,
    MessageSenders,
    ChatMessageSender,
    ChatMessageSenders,
    MessageReadDateRead,
    MessageReadDateUnread,
    MessageReadDateTooOld,
    MessageReadDateUserPrivacyRestricted,
    MessageReadDateMyPrivacyRestricted,
    MessageViewer,
    MessageViewers,
    MessageOriginUser,
    MessageOriginHiddenUser,
    MessageOriginChat,
    MessageOriginChannel,
    ForwardSource,
    ReactionTypeEmoji,
    ReactionTypeCustomEmoji,
    ReactionTypePaid,
    PaidReactionTypeRegular,
    PaidReactionTypeAnonymous,
    PaidReactionTypeChat,
    PaidReactor,
    MessageForwardInfo,
    MessageImportInfo,
    MessageReplyInfo,
    MessageReaction,
    MessageReactions,
    MessageInteractionInfo,
    UnreadReaction,
    MessageTopicForum,
    MessageTopicDirectMessages,
    MessageTopicSavedMessages,
    MessageEffectTypeEmojiReaction,
    MessageEffectTypePremiumSticker,
    MessageEffect,
    MessageSendingStatePending,
    MessageSendingStateFailed,
    TextQuote,
    InputTextQuote,
    MessageReplyToMessage,
    MessageReplyToStory,
    InputMessageReplyToMessage,
    InputMessageReplyToExternalMessage,
    InputMessageReplyToStory,
    FactCheck,
    Message,
    Messages,
    FoundMessages,
    FoundChatMessages,
    FoundPublicPosts,
    MessagePosition,
    MessagePositions,
    MessageCalendarDay,
    MessageCalendar,
    BusinessMessage,
    BusinessMessages,
    MessageSourceChatHistory,
    MessageSourceMessageThreadHistory,
    MessageSourceForumTopicHistory,
    MessageSourceDirectMessagesChatTopicHistory,
    MessageSourceHistoryPreview,
    MessageSourceChatList,
    MessageSourceSearch,
    MessageSourceChatEventLog,
    MessageSourceNotification,
    MessageSourceScreenshot,
    MessageSourceOther,
    AdvertisementSponsor,
    SponsoredMessage,
    SponsoredMessages,
    SponsoredChat,
    SponsoredChats,
    VideoMessageAdvertisement,
    VideoMessageAdvertisements,
    ReportOption,
    ReportSponsoredResultOk,
    ReportSponsoredResultFailed,
    ReportSponsoredResultOptionRequired,
    ReportSponsoredResultAdsHidden,
    ReportSponsoredResultPremiumRequired,
    FileDownload,
    DownloadedFileCounts,
    FoundFileDownloads,
    NotificationSettingsScopePrivateChats,
    NotificationSettingsScopeGroupChats,
    NotificationSettingsScopeChannelChats,
    ChatNotificationSettings,
    ScopeNotificationSettings,
    ReactionNotificationSourceNone,
    ReactionNotificationSourceContacts,
    ReactionNotificationSourceAll,
    ReactionNotificationSettings,
    DraftMessage,
    ChatTypePrivate,
    ChatTypeBasicGroup,
    ChatTypeSupergroup,
    ChatTypeSecret,
    ChatFolderIcon,
    ChatFolderName,
    ChatFolder,
    ChatFolderInfo,
    ChatFolderInviteLink,
    ChatFolderInviteLinks,
    ChatFolderInviteLinkInfo,
    RecommendedChatFolder,
    RecommendedChatFolders,
    ArchiveChatListSettings,
    ChatListMain,
    ChatListArchive,
    ChatListFolder,
    ChatLists,
    ChatSourceMtprotoProxy,
    ChatSourcePublicServiceAnnouncement,
    ChatPosition,
    ChatAvailableReactionsAll,
    ChatAvailableReactionsSome,
    SavedMessagesTag,
    SavedMessagesTags,
    BusinessBotManageBar,
    VideoChat,
    Chat,
    Chats,
    FailedToAddMember,
    FailedToAddMembers,
    CreatedBasicGroupChat,
    PublicChatTypeHasUsername,
    PublicChatTypeIsLocationBased,
    AccountInfo,
    ChatActionBarReportSpam,
    ChatActionBarInviteMembers,
    ChatActionBarReportAddBlock,
    ChatActionBarAddContact,
    ChatActionBarSharePhoneNumber,
    ChatActionBarJoinRequest,
    KeyboardButtonTypeText,
    KeyboardButtonTypeRequestPhoneNumber,
    KeyboardButtonTypeRequestLocation,
    KeyboardButtonTypeRequestPoll,
    KeyboardButtonTypeRequestUsers,
    KeyboardButtonTypeRequestChat,
    KeyboardButtonTypeWebApp,
    KeyboardButton,
    InlineKeyboardButtonTypeUrl,
    InlineKeyboardButtonTypeLoginUrl,
    InlineKeyboardButtonTypeWebApp,
    InlineKeyboardButtonTypeCallback,
    InlineKeyboardButtonTypeCallbackWithPassword,
    InlineKeyboardButtonTypeCallbackGame,
    InlineKeyboardButtonTypeSwitchInline,
    InlineKeyboardButtonTypeBuy,
    InlineKeyboardButtonTypeUser,
    InlineKeyboardButtonTypeCopyText,
    InlineKeyboardButton,
    ReplyMarkupRemoveKeyboard,
    ReplyMarkupForceReply,
    ReplyMarkupShowKeyboard,
    ReplyMarkupInlineKeyboard,
    LoginUrlInfoOpen,
    LoginUrlInfoRequestConfirmation,
    ThemeParameters,
    WebAppOpenModeCompact,
    WebAppOpenModeFullSize,
    WebAppOpenModeFullScreen,
    FoundWebApp,
    WebAppInfo,
    MainWebApp,
    WebAppOpenParameters,
    MessageThreadInfo,
    SavedMessagesTopicTypeMyNotes,
    SavedMessagesTopicTypeAuthorHidden,
    SavedMessagesTopicTypeSavedFromChat,
    SavedMessagesTopic,
    DirectMessagesChatTopic,
    ForumTopicIcon,
    ForumTopicInfo,
    ForumTopic,
    ForumTopics,
    LinkPreviewOptions,
    SharedUser,
    SharedChat,
    BuiltInThemeClassic,
    BuiltInThemeDay,
    BuiltInThemeNight,
    BuiltInThemeTinted,
    BuiltInThemeArctic,
    ThemeSettings,
    RichTextPlain,
    RichTextBold,
    RichTextItalic,
    RichTextUnderline,
    RichTextStrikethrough,
    RichTextFixed,
    RichTextUrl,
    RichTextEmailAddress,
    RichTextSubscript,
    RichTextSuperscript,
    RichTextMarked,
    RichTextPhoneNumber,
    RichTextIcon,
    RichTextReference,
    RichTextAnchor,
    RichTextAnchorLink,
    RichTexts,
    PageBlockCaption,
    PageBlockListItem,
    PageBlockHorizontalAlignmentLeft,
    PageBlockHorizontalAlignmentCenter,
    PageBlockHorizontalAlignmentRight,
    PageBlockVerticalAlignmentTop,
    PageBlockVerticalAlignmentMiddle,
    PageBlockVerticalAlignmentBottom,
    PageBlockTableCell,
    PageBlockRelatedArticle,
    PageBlockTitle,
    PageBlockSubtitle,
    PageBlockAuthorDate,
    PageBlockHeader,
    PageBlockSubheader,
    PageBlockKicker,
    PageBlockParagraph,
    PageBlockPreformatted,
    PageBlockFooter,
    PageBlockDivider,
    PageBlockAnchor,
    PageBlockList,
    PageBlockBlockQuote,
    PageBlockPullQuote,
    PageBlockAnimation,
    PageBlockAudio,
    PageBlockPhoto,
    PageBlockVideo,
    PageBlockVoiceNote,
    PageBlockCover,
    PageBlockEmbedded,
    PageBlockEmbeddedPost,
    PageBlockCollage,
    PageBlockSlideshow,
    PageBlockChatLink,
    PageBlockTable,
    PageBlockDetails,
    PageBlockRelatedArticles,
    PageBlockMap,
    WebPageInstantView,
    LinkPreviewAlbumMediaPhoto,
    LinkPreviewAlbumMediaVideo,
    LinkPreviewTypeAlbum,
    LinkPreviewTypeAnimation,
    LinkPreviewTypeApp,
    LinkPreviewTypeArticle,
    LinkPreviewTypeAudio,
    LinkPreviewTypeBackground,
    LinkPreviewTypeChannelBoost,
    LinkPreviewTypeChat,
    LinkPreviewTypeDirectMessagesChat,
    LinkPreviewTypeDocument,
    LinkPreviewTypeEmbeddedAnimationPlayer,
    LinkPreviewTypeEmbeddedAudioPlayer,
    LinkPreviewTypeEmbeddedVideoPlayer,
    LinkPreviewTypeExternalAudio,
    LinkPreviewTypeExternalVideo,
    LinkPreviewTypeGiftCollection,
    LinkPreviewTypeGroupCall,
    LinkPreviewTypeInvoice,
    LinkPreviewTypeMessage,
    LinkPreviewTypePhoto,
    LinkPreviewTypePremiumGiftCode,
    LinkPreviewTypeShareableChatFolder,
    LinkPreviewTypeSticker,
    LinkPreviewTypeStickerSet,
    LinkPreviewTypeStory,
    LinkPreviewTypeStoryAlbum,
    LinkPreviewTypeSupergroupBoost,
    LinkPreviewTypeTheme,
    LinkPreviewTypeUnsupported,
    LinkPreviewTypeUpgradedGift,
    LinkPreviewTypeUser,
    LinkPreviewTypeVideo,
    LinkPreviewTypeVideoChat,
    LinkPreviewTypeVideoNote,
    LinkPreviewTypeVoiceNote,
    LinkPreviewTypeWebApp,
    LinkPreview,
    CountryInfo,
    Countries,
    PhoneNumberInfo,
    CollectibleItemTypeUsername,
    CollectibleItemTypePhoneNumber,
    CollectibleItemInfo,
    BankCardActionOpenUrl,
    BankCardInfo,
    Address,
    LocationAddress,
    LabeledPricePart,
    Invoice,
    OrderInfo,
    ShippingOption,
    SavedCredentials,
    InputCredentialsSaved,
    InputCredentialsNew,
    InputCredentialsApplePay,
    InputCredentialsGooglePay,
    PaymentProviderSmartGlocal,
    PaymentProviderStripe,
    PaymentProviderOther,
    PaymentOption,
    PaymentFormTypeRegular,
    PaymentFormTypeStars,
    PaymentFormTypeStarSubscription,
    PaymentForm,
    ValidatedOrderInfo,
    PaymentResult,
    PaymentReceiptTypeRegular,
    PaymentReceiptTypeStars,
    PaymentReceipt,
    InputInvoiceMessage,
    InputInvoiceName,
    InputInvoiceTelegram,
    PaidMediaPreview,
    PaidMediaPhoto,
    PaidMediaVideo,
    PaidMediaUnsupported,
    GiveawayParameters,
    DatedFile,
    PassportElementTypePersonalDetails,
    PassportElementTypePassport,
    PassportElementTypeDriverLicense,
    PassportElementTypeIdentityCard,
    PassportElementTypeInternalPassport,
    PassportElementTypeAddress,
    PassportElementTypeUtilityBill,
    PassportElementTypeBankStatement,
    PassportElementTypeRentalAgreement,
    PassportElementTypePassportRegistration,
    PassportElementTypeTemporaryRegistration,
    PassportElementTypePhoneNumber,
    PassportElementTypeEmailAddress,
    Date,
    PersonalDetails,
    IdentityDocument,
    InputIdentityDocument,
    PersonalDocument,
    InputPersonalDocument,
    PassportElementPersonalDetails,
    PassportElementPassport,
    PassportElementDriverLicense,
    PassportElementIdentityCard,
    PassportElementInternalPassport,
    PassportElementAddress,
    PassportElementUtilityBill,
    PassportElementBankStatement,
    PassportElementRentalAgreement,
    PassportElementPassportRegistration,
    PassportElementTemporaryRegistration,
    PassportElementPhoneNumber,
    PassportElementEmailAddress,
    InputPassportElementPersonalDetails,
    InputPassportElementPassport,
    InputPassportElementDriverLicense,
    InputPassportElementIdentityCard,
    InputPassportElementInternalPassport,
    InputPassportElementAddress,
    InputPassportElementUtilityBill,
    InputPassportElementBankStatement,
    InputPassportElementRentalAgreement,
    InputPassportElementPassportRegistration,
    InputPassportElementTemporaryRegistration,
    InputPassportElementPhoneNumber,
    InputPassportElementEmailAddress,
    PassportElements,
    PassportElementErrorSourceUnspecified,
    PassportElementErrorSourceDataField,
    PassportElementErrorSourceFrontSide,
    PassportElementErrorSourceReverseSide,
    PassportElementErrorSourceSelfie,
    PassportElementErrorSourceTranslationFile,
    PassportElementErrorSourceTranslationFiles,
    PassportElementErrorSourceFile,
    PassportElementErrorSourceFiles,
    PassportElementError,
    PassportSuitableElement,
    PassportRequiredElement,
    PassportAuthorizationForm,
    PassportElementsWithErrors,
    EncryptedCredentials,
    EncryptedPassportElement,
    InputPassportElementErrorSourceUnspecified,
    InputPassportElementErrorSourceDataField,
    InputPassportElementErrorSourceFrontSide,
    InputPassportElementErrorSourceReverseSide,
    InputPassportElementErrorSourceSelfie,
    InputPassportElementErrorSourceTranslationFile,
    InputPassportElementErrorSourceTranslationFiles,
    InputPassportElementErrorSourceFile,
    InputPassportElementErrorSourceFiles,
    InputPassportElementError,
    MessageText,
    MessageAnimation,
    MessageAudio,
    MessageDocument,
    MessagePaidMedia,
    MessagePhoto,
    MessageSticker,
    MessageVideo,
    MessageVideoNote,
    MessageVoiceNote,
    MessageExpiredPhoto,
    MessageExpiredVideo,
    MessageExpiredVideoNote,
    MessageExpiredVoiceNote,
    MessageLocation,
    MessageVenue,
    MessageContact,
    MessageAnimatedEmoji,
    MessageDice,
    MessageGame,
    MessagePoll,
    MessageStory,
    MessageChecklist,
    MessageInvoice,
    MessageCall,
    MessageGroupCall,
    MessageVideoChatScheduled,
    MessageVideoChatStarted,
    MessageVideoChatEnded,
    MessageInviteVideoChatParticipants,
    MessageBasicGroupChatCreate,
    MessageSupergroupChatCreate,
    MessageChatChangeTitle,
    MessageChatChangePhoto,
    MessageChatDeletePhoto,
    MessageChatAddMembers,
    MessageChatJoinByLink,
    MessageChatJoinByRequest,
    MessageChatDeleteMember,
    MessageChatUpgradeTo,
    MessageChatUpgradeFrom,
    MessagePinMessage,
    MessageScreenshotTaken,
    MessageChatSetBackground,
    MessageChatSetTheme,
    MessageChatSetMessageAutoDeleteTime,
    MessageChatBoost,
    MessageForumTopicCreated,
    MessageForumTopicEdited,
    MessageForumTopicIsClosedToggled,
    MessageForumTopicIsHiddenToggled,
    MessageSuggestProfilePhoto,
    MessageCustomServiceAction,
    MessageGameScore,
    MessagePaymentSuccessful,
    MessagePaymentSuccessfulBot,
    MessagePaymentRefunded,
    MessageGiftedPremium,
    MessagePremiumGiftCode,
    MessageGiveawayCreated,
    MessageGiveaway,
    MessageGiveawayCompleted,
    MessageGiveawayWinners,
    MessageGiftedStars,
    MessageGiftedTon,
    MessageGiveawayPrizeStars,
    MessageGift,
    MessageUpgradedGift,
    MessageRefundedUpgradedGift,
    MessagePaidMessagesRefunded,
    MessagePaidMessagePriceChanged,
    MessageDirectMessagePriceChanged,
    MessageChecklistTasksDone,
    MessageChecklistTasksAdded,
    MessageSuggestedPostApprovalFailed,
    MessageSuggestedPostApproved,
    MessageSuggestedPostDeclined,
    MessageSuggestedPostPaid,
    MessageSuggestedPostRefunded,
    MessageContactRegistered,
    MessageUsersShared,
    MessageChatShared,
    MessageBotWriteAccessAllowed,
    MessageWebAppDataSent,
    MessageWebAppDataReceived,
    MessagePassportDataSent,
    MessagePassportDataReceived,
    MessageProximityAlertTriggered,
    MessageUnsupported,
    TextEntityTypeMention,
    TextEntityTypeHashtag,
    TextEntityTypeCashtag,
    TextEntityTypeBotCommand,
    TextEntityTypeUrl,
    TextEntityTypeEmailAddress,
    TextEntityTypePhoneNumber,
    TextEntityTypeBankCardNumber,
    TextEntityTypeBold,
    TextEntityTypeItalic,
    TextEntityTypeUnderline,
    TextEntityTypeStrikethrough,
    TextEntityTypeSpoiler,
    TextEntityTypeCode,
    TextEntityTypePre,
    TextEntityTypePreCode,
    TextEntityTypeBlockQuote,
    TextEntityTypeExpandableBlockQuote,
    TextEntityTypeTextUrl,
    TextEntityTypeMentionName,
    TextEntityTypeCustomEmoji,
    TextEntityTypeMediaTimestamp,
    InputThumbnail,
    InputPaidMediaTypePhoto,
    InputPaidMediaTypeVideo,
    InputPaidMedia,
    MessageSchedulingStateSendAtDate,
    MessageSchedulingStateSendWhenOnline,
    MessageSchedulingStateSendWhenVideoProcessed,
    MessageSelfDestructTypeTimer,
    MessageSelfDestructTypeImmediately,
    MessageSendOptions,
    MessageCopyOptions,
    InputMessageText,
    InputMessageAnimation,
    InputMessageAudio,
    InputMessageDocument,
    InputMessagePaidMedia,
    InputMessagePhoto,
    InputMessageSticker,
    InputMessageVideo,
    InputMessageVideoNote,
    InputMessageVoiceNote,
    InputMessageLocation,
    InputMessageVenue,
    InputMessageContact,
    InputMessageDice,
    InputMessageGame,
    InputMessageInvoice,
    InputMessagePoll,
    InputMessageStory,
    InputMessageChecklist,
    InputMessageForwarded,
    MessageProperties,
    SearchMessagesFilterEmpty,
    SearchMessagesFilterAnimation,
    SearchMessagesFilterAudio,
    SearchMessagesFilterDocument,
    SearchMessagesFilterPhoto,
    SearchMessagesFilterVideo,
    SearchMessagesFilterVoiceNote,
    SearchMessagesFilterPhotoAndVideo,
    SearchMessagesFilterUrl,
    SearchMessagesFilterChatPhoto,
    SearchMessagesFilterVideoNote,
    SearchMessagesFilterVoiceAndVideoNote,
    SearchMessagesFilterMention,
    SearchMessagesFilterUnreadMention,
    SearchMessagesFilterUnreadReaction,
    SearchMessagesFilterFailedToSend,
    SearchMessagesFilterPinned,
    SearchMessagesChatTypeFilterPrivate,
    SearchMessagesChatTypeFilterGroup,
    SearchMessagesChatTypeFilterChannel,
    ChatActionTyping,
    ChatActionRecordingVideo,
    ChatActionUploadingVideo,
    ChatActionRecordingVoiceNote,
    ChatActionUploadingVoiceNote,
    ChatActionUploadingPhoto,
    ChatActionUploadingDocument,
    ChatActionChoosingSticker,
    ChatActionChoosingLocation,
    ChatActionChoosingContact,
    ChatActionStartPlayingGame,
    ChatActionRecordingVideoNote,
    ChatActionUploadingVideoNote,
    ChatActionWatchingAnimations,
    ChatActionCancel,
    UserStatusEmpty,
    UserStatusOnline,
    UserStatusOffline,
    UserStatusRecently,
    UserStatusLastWeek,
    UserStatusLastMonth,
    EmojiKeyword,
    EmojiKeywords,
    Stickers,
    Emojis,
    StickerSet,
    StickerSetInfo,
    StickerSets,
    TrendingStickerSets,
    EmojiCategorySourceSearch,
    EmojiCategorySourcePremium,
    EmojiCategory,
    EmojiCategories,
    EmojiCategoryTypeDefault,
    EmojiCategoryTypeRegularStickers,
    EmojiCategoryTypeEmojiStatus,
    EmojiCategoryTypeChatPhoto,
    CurrentWeather,
    StoryAreaPosition,
    StoryAreaTypeLocation,
    StoryAreaTypeVenue,
    StoryAreaTypeSuggestedReaction,
    StoryAreaTypeMessage,
    StoryAreaTypeLink,
    StoryAreaTypeWeather,
    StoryAreaTypeUpgradedGift,
    StoryArea,
    InputStoryAreaTypeLocation,
    InputStoryAreaTypeFoundVenue,
    InputStoryAreaTypePreviousVenue,
    InputStoryAreaTypeSuggestedReaction,
    InputStoryAreaTypeMessage,
    InputStoryAreaTypeLink,
    InputStoryAreaTypeWeather,
    InputStoryAreaTypeUpgradedGift,
    InputStoryArea,
    InputStoryAreas,
    StoryVideo,
    StoryContentPhoto,
    StoryContentVideo,
    StoryContentUnsupported,
    InputStoryContentPhoto,
    InputStoryContentVideo,
    StoryListMain,
    StoryListArchive,
    StoryOriginPublicStory,
    StoryOriginHiddenUser,
    StoryRepostInfo,
    StoryInteractionInfo,
    Story,
    Stories,
    FoundStories,
    StoryAlbum,
    StoryAlbums,
    StoryFullId,
    StoryInfo,
    ChatActiveStories,
    StoryInteractionTypeView,
    StoryInteractionTypeForward,
    StoryInteractionTypeRepost,
    StoryInteraction,
    StoryInteractions,
    QuickReplyMessage,
    QuickReplyMessages,
    QuickReplyShortcut,
    PublicForwardMessage,
    PublicForwardStory,
    PublicForwards,
    BotMediaPreview,
    BotMediaPreviews,
    BotMediaPreviewInfo,
    ChatBoostLevelFeatures,
    ChatBoostFeatures,
    ChatBoostSourceGiftCode,
    ChatBoostSourceGiveaway,
    ChatBoostSourcePremium,
    PrepaidGiveaway,
    ChatBoostStatus,
    ChatBoost,
    FoundChatBoosts,
    ChatBoostSlot,
    ChatBoostSlots,
    ResendCodeReasonUserRequest,
    ResendCodeReasonVerificationFailed,
    CallDiscardReasonEmpty,
    CallDiscardReasonMissed,
    CallDiscardReasonDeclined,
    CallDiscardReasonDisconnected,
    CallDiscardReasonHungUp,
    CallDiscardReasonUpgradeToGroupCall,
    CallProtocol,
    CallServerTypeTelegramReflector,
    CallServerTypeWebrtc,
    CallServer,
    CallId,
    GroupCallId,
    CallStatePending,
    CallStateExchangingKeys,
    CallStateReady,
    CallStateHangingUp,
    CallStateDiscarded,
    CallStateError,
    GroupCallJoinParameters,
    GroupCallVideoQualityThumbnail,
    GroupCallVideoQualityMedium,
    GroupCallVideoQualityFull,
    VideoChatStream,
    VideoChatStreams,
    RtmpUrl,
    GroupCallRecentSpeaker,
    GroupCall,
    GroupCallVideoSourceGroup,
    GroupCallParticipantVideoInfo,
    GroupCallParticipant,
    GroupCallParticipants,
    GroupCallInfo,
    InviteGroupCallParticipantResultUserPrivacyRestricted,
    InviteGroupCallParticipantResultUserAlreadyParticipant,
    InviteGroupCallParticipantResultUserWasBanned,
    InviteGroupCallParticipantResultSuccess,
    GroupCallDataChannelMain,
    GroupCallDataChannelScreenSharing,
    InputGroupCallLink,
    InputGroupCallMessage,
    CallProblemEcho,
    CallProblemNoise,
    CallProblemInterruptions,
    CallProblemDistortedSpeech,
    CallProblemSilentLocal,
    CallProblemSilentRemote,
    CallProblemDropped,
    CallProblemDistortedVideo,
    CallProblemPixelatedVideo,
    Call,
    FirebaseAuthenticationSettingsAndroid,
    FirebaseAuthenticationSettingsIos,
    PhoneNumberAuthenticationSettings,
    AddedReaction,
    AddedReactions,
    AvailableReaction,
    AvailableReactions,
    EmojiReaction,
    ReactionUnavailabilityReasonAnonymousAdministrator,
    ReactionUnavailabilityReasonGuest,
    Animations,
    DiceStickersRegular,
    DiceStickersSlotMachine,
    ImportedContacts,
    SpeechRecognitionResultPending,
    SpeechRecognitionResultText,
    SpeechRecognitionResultError,
    BusinessConnection,
    AttachmentMenuBotColor,
    AttachmentMenuBot,
    SentWebAppMessage,
    BotWriteAccessAllowReasonConnectedWebsite,
    BotWriteAccessAllowReasonAddedToAttachmentMenu,
    BotWriteAccessAllowReasonLaunchedWebApp,
    BotWriteAccessAllowReasonAcceptedRequest,
    HttpUrl,
    UserLink,
    TargetChatTypes,
    TargetChatCurrent,
    TargetChatChosen,
    TargetChatInternalLink,
    InputInlineQueryResultAnimation,
    InputInlineQueryResultArticle,
    InputInlineQueryResultAudio,
    InputInlineQueryResultContact,
    InputInlineQueryResultDocument,
    InputInlineQueryResultGame,
    InputInlineQueryResultLocation,
    InputInlineQueryResultPhoto,
    InputInlineQueryResultSticker,
    InputInlineQueryResultVenue,
    InputInlineQueryResultVideo,
    InputInlineQueryResultVoiceNote,
    InlineQueryResultArticle,
    InlineQueryResultContact,
    InlineQueryResultLocation,
    InlineQueryResultVenue,
    InlineQueryResultGame,
    InlineQueryResultAnimation,
    InlineQueryResultAudio,
    InlineQueryResultDocument,
    InlineQueryResultPhoto,
    InlineQueryResultSticker,
    InlineQueryResultVideo,
    InlineQueryResultVoiceNote,
    InlineQueryResultsButtonTypeStartBot,
    InlineQueryResultsButtonTypeWebApp,
    InlineQueryResultsButton,
    InlineQueryResults,
    PreparedInlineMessageId,
    PreparedInlineMessage,
    CallbackQueryPayloadData,
    CallbackQueryPayloadDataWithPassword,
    CallbackQueryPayloadGame,
    CallbackQueryAnswer,
    CustomRequestResult,
    GameHighScore,
    GameHighScores,
    ChatEventMessageEdited,
    ChatEventMessageDeleted,
    ChatEventMessagePinned,
    ChatEventMessageUnpinned,
    ChatEventPollStopped,
    ChatEventMemberJoined,
    ChatEventMemberJoinedByInviteLink,
    ChatEventMemberJoinedByRequest,
    ChatEventMemberInvited,
    ChatEventMemberLeft,
    ChatEventMemberPromoted,
    ChatEventMemberRestricted,
    ChatEventMemberSubscriptionExtended,
    ChatEventAvailableReactionsChanged,
    ChatEventBackgroundChanged,
    ChatEventDescriptionChanged,
    ChatEventEmojiStatusChanged,
    ChatEventLinkedChatChanged,
    ChatEventLocationChanged,
    ChatEventMessageAutoDeleteTimeChanged,
    ChatEventPermissionsChanged,
    ChatEventPhotoChanged,
    ChatEventSlowModeDelayChanged,
    ChatEventStickerSetChanged,
    ChatEventCustomEmojiStickerSetChanged,
    ChatEventTitleChanged,
    ChatEventUsernameChanged,
    ChatEventActiveUsernamesChanged,
    ChatEventAccentColorChanged,
    ChatEventProfileAccentColorChanged,
    ChatEventHasProtectedContentToggled,
    ChatEventInvitesToggled,
    ChatEventIsAllHistoryAvailableToggled,
    ChatEventHasAggressiveAntiSpamEnabledToggled,
    ChatEventSignMessagesToggled,
    ChatEventShowMessageSenderToggled,
    ChatEventAutomaticTranslationToggled,
    ChatEventInviteLinkEdited,
    ChatEventInviteLinkRevoked,
    ChatEventInviteLinkDeleted,
    ChatEventVideoChatCreated,
    ChatEventVideoChatEnded,
    ChatEventVideoChatMuteNewParticipantsToggled,
    ChatEventVideoChatParticipantIsMutedToggled,
    ChatEventVideoChatParticipantVolumeLevelChanged,
    ChatEventIsForumToggled,
    ChatEventForumTopicCreated,
    ChatEventForumTopicEdited,
    ChatEventForumTopicToggleIsClosed,
    ChatEventForumTopicToggleIsHidden,
    ChatEventForumTopicDeleted,
    ChatEventForumTopicPinned,
    ChatEvent,
    ChatEvents,
    ChatEventLogFilters,
    LanguagePackStringValueOrdinary,
    LanguagePackStringValuePluralized,
    LanguagePackStringValueDeleted,
    LanguagePackString,
    LanguagePackStrings,
    LanguagePackInfo,
    LocalizationTargetInfo,
    PremiumLimitTypeSupergroupCount,
    PremiumLimitTypePinnedChatCount,
    PremiumLimitTypeCreatedPublicChatCount,
    PremiumLimitTypeSavedAnimationCount,
    PremiumLimitTypeFavoriteStickerCount,
    PremiumLimitTypeChatFolderCount,
    PremiumLimitTypeChatFolderChosenChatCount,
    PremiumLimitTypePinnedArchivedChatCount,
    PremiumLimitTypePinnedSavedMessagesTopicCount,
    PremiumLimitTypeCaptionLength,
    PremiumLimitTypeBioLength,
    PremiumLimitTypeChatFolderInviteLinkCount,
    PremiumLimitTypeShareableChatFolderCount,
    PremiumLimitTypeActiveStoryCount,
    PremiumLimitTypeWeeklyPostedStoryCount,
    PremiumLimitTypeMonthlyPostedStoryCount,
    PremiumLimitTypeStoryCaptionLength,
    PremiumLimitTypeStorySuggestedReactionAreaCount,
    PremiumLimitTypeSimilarChatCount,
    PremiumFeatureIncreasedLimits,
    PremiumFeatureIncreasedUploadFileSize,
    PremiumFeatureImprovedDownloadSpeed,
    PremiumFeatureVoiceRecognition,
    PremiumFeatureDisabledAds,
    PremiumFeatureUniqueReactions,
    PremiumFeatureUniqueStickers,
    PremiumFeatureCustomEmoji,
    PremiumFeatureAdvancedChatManagement,
    PremiumFeatureProfileBadge,
    PremiumFeatureEmojiStatus,
    PremiumFeatureAnimatedProfilePhoto,
    PremiumFeatureForumTopicIcon,
    PremiumFeatureAppIcons,
    PremiumFeatureRealTimeChatTranslation,
    PremiumFeatureUpgradedStories,
    PremiumFeatureChatBoost,
    PremiumFeatureAccentColor,
    PremiumFeatureBackgroundForBoth,
    PremiumFeatureSavedMessagesTags,
    PremiumFeatureMessagePrivacy,
    PremiumFeatureLastSeenTimes,
    PremiumFeatureBusiness,
    PremiumFeatureMessageEffects,
    PremiumFeatureChecklists,
    BusinessFeatureLocation,
    BusinessFeatureOpeningHours,
    BusinessFeatureQuickReplies,
    BusinessFeatureGreetingMessage,
    BusinessFeatureAwayMessage,
    BusinessFeatureAccountLinks,
    BusinessFeatureStartPage,
    BusinessFeatureBots,
    BusinessFeatureEmojiStatus,
    BusinessFeatureChatFolderTags,
    BusinessFeatureUpgradedStories,
    PremiumStoryFeaturePriorityOrder,
    PremiumStoryFeatureStealthMode,
    PremiumStoryFeaturePermanentViewsHistory,
    PremiumStoryFeatureCustomExpirationDuration,
    PremiumStoryFeatureSaveStories,
    PremiumStoryFeatureLinksAndFormatting,
    PremiumStoryFeatureVideoQuality,
    PremiumLimit,
    PremiumFeatures,
    BusinessFeatures,
    PremiumSourceLimitExceeded,
    PremiumSourceFeature,
    PremiumSourceBusinessFeature,
    PremiumSourceStoryFeature,
    PremiumSourceLink,
    PremiumSourceSettings,
    PremiumFeaturePromotionAnimation,
    BusinessFeaturePromotionAnimation,
    PremiumState,
    StorePaymentPurposePremiumSubscription,
    StorePaymentPurposePremiumGift,
    StorePaymentPurposePremiumGiftCodes,
    StorePaymentPurposePremiumGiveaway,
    StorePaymentPurposeStarGiveaway,
    StorePaymentPurposeStars,
    StorePaymentPurposeGiftedStars,
    StoreTransactionAppStore,
    StoreTransactionGooglePlay,
    TelegramPaymentPurposePremiumGift,
    TelegramPaymentPurposePremiumGiftCodes,
    TelegramPaymentPurposePremiumGiveaway,
    TelegramPaymentPurposeStars,
    TelegramPaymentPurposeGiftedStars,
    TelegramPaymentPurposeStarGiveaway,
    TelegramPaymentPurposeJoinChat,
    DeviceTokenFirebaseCloudMessaging,
    DeviceTokenApplePush,
    DeviceTokenApplePushVoIP,
    DeviceTokenWindowsPush,
    DeviceTokenMicrosoftPush,
    DeviceTokenMicrosoftPushVoIP,
    DeviceTokenWebPush,
    DeviceTokenSimplePush,
    DeviceTokenUbuntuPush,
    DeviceTokenBlackBerryPush,
    DeviceTokenTizenPush,
    DeviceTokenHuaweiPush,
    PushReceiverId,
    BackgroundFillSolid,
    BackgroundFillGradient,
    BackgroundFillFreeformGradient,
    BackgroundTypeWallpaper,
    BackgroundTypePattern,
    BackgroundTypeFill,
    BackgroundTypeChatTheme,
    InputBackgroundLocal,
    InputBackgroundRemote,
    InputBackgroundPrevious,
    EmojiChatTheme,
    GiftChatTheme,
    GiftChatThemes,
    ChatThemeEmoji,
    ChatThemeGift,
    InputChatThemeEmoji,
    InputChatThemeGift,
    TimeZone,
    TimeZones,
    Hashtags,
    CanPostStoryResultOk,
    CanPostStoryResultPremiumNeeded,
    CanPostStoryResultBoostNeeded,
    CanPostStoryResultActiveStoryLimitExceeded,
    CanPostStoryResultWeeklyLimitExceeded,
    CanPostStoryResultMonthlyLimitExceeded,
    CanTransferOwnershipResultOk,
    CanTransferOwnershipResultPasswordNeeded,
    CanTransferOwnershipResultPasswordTooFresh,
    CanTransferOwnershipResultSessionTooFresh,
    CheckChatUsernameResultOk,
    CheckChatUsernameResultUsernameInvalid,
    CheckChatUsernameResultUsernameOccupied,
    CheckChatUsernameResultUsernamePurchasable,
    CheckChatUsernameResultPublicChatsTooMany,
    CheckChatUsernameResultPublicGroupsUnavailable,
    CheckStickerSetNameResultOk,
    CheckStickerSetNameResultNameInvalid,
    CheckStickerSetNameResultNameOccupied,
    ResetPasswordResultOk,
    ResetPasswordResultPending,
    ResetPasswordResultDeclined,
    MessageFileTypePrivate,
    MessageFileTypeGroup,
    MessageFileTypeUnknown,
    PushMessageContentHidden,
    PushMessageContentAnimation,
    PushMessageContentAudio,
    PushMessageContentContact,
    PushMessageContentContactRegistered,
    PushMessageContentDocument,
    PushMessageContentGame,
    PushMessageContentGameScore,
    PushMessageContentInvoice,
    PushMessageContentLocation,
    PushMessageContentPaidMedia,
    PushMessageContentPhoto,
    PushMessageContentPoll,
    PushMessageContentPremiumGiftCode,
    PushMessageContentGiveaway,
    PushMessageContentGift,
    PushMessageContentUpgradedGift,
    PushMessageContentScreenshotTaken,
    PushMessageContentSticker,
    PushMessageContentStory,
    PushMessageContentText,
    PushMessageContentChecklist,
    PushMessageContentVideo,
    PushMessageContentVideoNote,
    PushMessageContentVoiceNote,
    PushMessageContentBasicGroupChatCreate,
    PushMessageContentVideoChatStarted,
    PushMessageContentVideoChatEnded,
    PushMessageContentInviteVideoChatParticipants,
    PushMessageContentChatAddMembers,
    PushMessageContentChatChangePhoto,
    PushMessageContentChatChangeTitle,
    PushMessageContentChatSetBackground,
    PushMessageContentChatSetTheme,
    PushMessageContentChatDeleteMember,
    PushMessageContentChatJoinByLink,
    PushMessageContentChatJoinByRequest,
    PushMessageContentRecurringPayment,
    PushMessageContentSuggestProfilePhoto,
    PushMessageContentProximityAlertTriggered,
    PushMessageContentChecklistTasksAdded,
    PushMessageContentChecklistTasksDone,
    PushMessageContentMessageForwards,
    PushMessageContentMediaAlbum,
    NotificationTypeNewMessage,
    NotificationTypeNewSecretChat,
    NotificationTypeNewCall,
    NotificationTypeNewPushMessage,
    NotificationGroupTypeMessages,
    NotificationGroupTypeMentions,
    NotificationGroupTypeSecretChat,
    NotificationGroupTypeCalls,
    NotificationSound,
    NotificationSounds,
    Notification,
    NotificationGroup,
    OptionValueBoolean,
    OptionValueEmpty,
    OptionValueInteger,
    OptionValueString,
    JsonObjectMember,
    JsonValueNull,
    JsonValueBoolean,
    JsonValueNumber,
    JsonValueString,
    JsonValueArray,
    JsonValueObject,
    StoryPrivacySettingsEveryone,
    StoryPrivacySettingsContacts,
    StoryPrivacySettingsCloseFriends,
    StoryPrivacySettingsSelectedUsers,
    UserPrivacySettingRuleAllowAll,
    UserPrivacySettingRuleAllowContacts,
    UserPrivacySettingRuleAllowBots,
    UserPrivacySettingRuleAllowPremiumUsers,
    UserPrivacySettingRuleAllowUsers,
    UserPrivacySettingRuleAllowChatMembers,
    UserPrivacySettingRuleRestrictAll,
    UserPrivacySettingRuleRestrictContacts,
    UserPrivacySettingRuleRestrictBots,
    UserPrivacySettingRuleRestrictUsers,
    UserPrivacySettingRuleRestrictChatMembers,
    UserPrivacySettingRules,
    UserPrivacySettingShowStatus,
    UserPrivacySettingShowProfilePhoto,
    UserPrivacySettingShowLinkInForwardedMessages,
    UserPrivacySettingShowPhoneNumber,
    UserPrivacySettingShowBio,
    UserPrivacySettingShowBirthdate,
    UserPrivacySettingAllowChatInvites,
    UserPrivacySettingAllowCalls,
    UserPrivacySettingAllowPeerToPeerCalls,
    UserPrivacySettingAllowFindingByPhoneNumber,
    UserPrivacySettingAllowPrivateVoiceAndVideoNoteMessages,
    UserPrivacySettingAutosaveGifts,
    UserPrivacySettingAllowUnpaidMessages,
    ReadDatePrivacySettings,
    NewChatPrivacySettings,
    CanSendMessageToUserResultOk,
    CanSendMessageToUserResultUserHasPaidMessages,
    CanSendMessageToUserResultUserIsDeleted,
    CanSendMessageToUserResultUserRestrictsNewChats,
    AccountTtl,
    MessageAutoDeleteTime,
    SessionTypeAndroid,
    SessionTypeApple,
    SessionTypeBrave,
    SessionTypeChrome,
    SessionTypeEdge,
    SessionTypeFirefox,
    SessionTypeIpad,
    SessionTypeIphone,
    SessionTypeLinux,
    SessionTypeMac,
    SessionTypeOpera,
    SessionTypeSafari,
    SessionTypeUbuntu,
    SessionTypeUnknown,
    SessionTypeVivaldi,
    SessionTypeWindows,
    SessionTypeXbox,
    Session,
    Sessions,
    UnconfirmedSession,
    ConnectedWebsite,
    ConnectedWebsites,
    ReportReasonSpam,
    ReportReasonViolence,
    ReportReasonPornography,
    ReportReasonChildAbuse,
    ReportReasonCopyright,
    ReportReasonUnrelatedLocation,
    ReportReasonFake,
    ReportReasonIllegalDrugs,
    ReportReasonPersonalDetails,
    ReportReasonCustom,
    ReportChatResultOk,
    ReportChatResultOptionRequired,
    ReportChatResultTextRequired,
    ReportChatResultMessagesRequired,
    ReportStoryResultOk,
    ReportStoryResultOptionRequired,
    ReportStoryResultTextRequired,
    InternalLinkTypeActiveSessions,
    InternalLinkTypeAttachmentMenuBot,
    InternalLinkTypeAuthenticationCode,
    InternalLinkTypeBackground,
    InternalLinkTypeBotAddToChannel,
    InternalLinkTypeBotStart,
    InternalLinkTypeBotStartInGroup,
    InternalLinkTypeBusinessChat,
    InternalLinkTypeBuyStars,
    InternalLinkTypeChangePhoneNumber,
    InternalLinkTypeChatAffiliateProgram,
    InternalLinkTypeChatBoost,
    InternalLinkTypeChatFolderInvite,
    InternalLinkTypeChatFolderSettings,
    InternalLinkTypeChatInvite,
    InternalLinkTypeDefaultMessageAutoDeleteTimerSettings,
    InternalLinkTypeDirectMessagesChat,
    InternalLinkTypeEditProfileSettings,
    InternalLinkTypeGame,
    InternalLinkTypeGiftCollection,
    InternalLinkTypeGroupCall,
    InternalLinkTypeInstantView,
    InternalLinkTypeInvoice,
    InternalLinkTypeLanguagePack,
    InternalLinkTypeLanguageSettings,
    InternalLinkTypeMainWebApp,
    InternalLinkTypeMessage,
    InternalLinkTypeMessageDraft,
    InternalLinkTypeMyStars,
    InternalLinkTypeMyToncoins,
    InternalLinkTypePassportDataRequest,
    InternalLinkTypePhoneNumberConfirmation,
    InternalLinkTypePremiumFeatures,
    InternalLinkTypePremiumGift,
    InternalLinkTypePremiumGiftCode,
    InternalLinkTypePrivacyAndSecuritySettings,
    InternalLinkTypeProxy,
    InternalLinkTypePublicChat,
    InternalLinkTypeQrCodeAuthentication,
    InternalLinkTypeRestorePurchases,
    InternalLinkTypeSettings,
    InternalLinkTypeStickerSet,
    InternalLinkTypeStory,
    InternalLinkTypeStoryAlbum,
    InternalLinkTypeTheme,
    InternalLinkTypeThemeSettings,
    InternalLinkTypeUnknownDeepLink,
    InternalLinkTypeUnsupportedProxy,
    InternalLinkTypeUpgradedGift,
    InternalLinkTypeUserPhoneNumber,
    InternalLinkTypeUserToken,
    InternalLinkTypeVideoChat,
    InternalLinkTypeWebApp,
    MessageLink,
    MessageLinkInfo,
    ChatBoostLink,
    ChatBoostLinkInfo,
    BlockListMain,
    BlockListStories,
    FileTypeNone,
    FileTypeAnimation,
    FileTypeAudio,
    FileTypeDocument,
    FileTypeNotificationSound,
    FileTypePhoto,
    FileTypePhotoStory,
    FileTypeProfilePhoto,
    FileTypeSecret,
    FileTypeSecretThumbnail,
    FileTypeSecure,
    FileTypeSelfDestructingPhoto,
    FileTypeSelfDestructingVideo,
    FileTypeSelfDestructingVideoNote,
    FileTypeSelfDestructingVoiceNote,
    FileTypeSticker,
    FileTypeThumbnail,
    FileTypeUnknown,
    FileTypeVideo,
    FileTypeVideoNote,
    FileTypeVideoStory,
    FileTypeVoiceNote,
    FileTypeWallpaper,
    StorageStatisticsByFileType,
    StorageStatisticsByChat,
    StorageStatistics,
    StorageStatisticsFast,
    DatabaseStatistics,
    NetworkTypeNone,
    NetworkTypeMobile,
    NetworkTypeMobileRoaming,
    NetworkTypeWiFi,
    NetworkTypeOther,
    NetworkStatisticsEntryFile,
    NetworkStatisticsEntryCall,
    NetworkStatistics,
    AutoDownloadSettings,
    AutoDownloadSettingsPresets,
    AutosaveSettingsScopePrivateChats,
    AutosaveSettingsScopeGroupChats,
    AutosaveSettingsScopeChannelChats,
    AutosaveSettingsScopeChat,
    ScopeAutosaveSettings,
    AutosaveSettingsException,
    AutosaveSettings,
    ConnectionStateWaitingForNetwork,
    ConnectionStateConnectingToProxy,
    ConnectionStateConnecting,
    ConnectionStateUpdating,
    ConnectionStateReady,
    AgeVerificationParameters,
    TopChatCategoryUsers,
    TopChatCategoryBots,
    TopChatCategoryGroups,
    TopChatCategoryChannels,
    TopChatCategoryInlineBots,
    TopChatCategoryWebAppBots,
    TopChatCategoryCalls,
    TopChatCategoryForwardChats,
    FoundPosition,
    FoundPositions,
    TMeUrlTypeUser,
    TMeUrlTypeSupergroup,
    TMeUrlTypeChatInvite,
    TMeUrlTypeStickerSet,
    TMeUrl,
    TMeUrls,
    SuggestedActionEnableArchiveAndMuteNewChats,
    SuggestedActionCheckPassword,
    SuggestedActionCheckPhoneNumber,
    SuggestedActionViewChecksHint,
    SuggestedActionConvertToBroadcastGroup,
    SuggestedActionSetPassword,
    SuggestedActionUpgradePremium,
    SuggestedActionRestorePremium,
    SuggestedActionSubscribeToAnnualPremium,
    SuggestedActionGiftPremiumForChristmas,
    SuggestedActionSetBirthdate,
    SuggestedActionSetProfilePhoto,
    SuggestedActionExtendPremium,
    SuggestedActionExtendStarSubscriptions,
    SuggestedActionCustom,
    Count,
    Text,
    Data,
    Seconds,
    FileDownloadedPrefixSize,
    StarCount,
    DeepLinkInfo,
    TextParseModeMarkdown,
    TextParseModeHTML,
    ProxyTypeSocks5,
    ProxyTypeHttp,
    ProxyTypeMtproto,
    Proxy,
    Proxies,
    InputSticker,
    DateRange,
    StatisticalValue,
    StatisticalGraphData,
    StatisticalGraphAsync,
    StatisticalGraphError,
    ChatStatisticsObjectTypeMessage,
    ChatStatisticsObjectTypeStory,
    ChatStatisticsInteractionInfo,
    ChatStatisticsMessageSenderInfo,
    ChatStatisticsAdministratorActionsInfo,
    ChatStatisticsInviterInfo,
    ChatStatisticsSupergroup,
    ChatStatisticsChannel,
    ChatRevenueAmount,
    ChatRevenueStatistics,
    MessageStatistics,
    StoryStatistics,
    RevenueWithdrawalStatePending,
    RevenueWithdrawalStateSucceeded,
    RevenueWithdrawalStateFailed,
    ChatRevenueTransactionTypeUnsupported,
    ChatRevenueTransactionTypeSponsoredMessageEarnings,
    ChatRevenueTransactionTypeSuggestedPostEarnings,
    ChatRevenueTransactionTypeFragmentWithdrawal,
    ChatRevenueTransactionTypeFragmentRefund,
    ChatRevenueTransaction,
    ChatRevenueTransactions,
    StarRevenueStatus,
    StarRevenueStatistics,
    TonRevenueStatus,
    TonRevenueStatistics,
    Point,
    VectorPathCommandLine,
    VectorPathCommandCubicBezierCurve,
    BotCommandScopeDefault,
    BotCommandScopeAllPrivateChats,
    BotCommandScopeAllGroupChats,
    BotCommandScopeAllChatAdministrators,
    BotCommandScopeChat,
    BotCommandScopeChatAdministrators,
    BotCommandScopeChatMember,
    PhoneNumberCodeTypeChange,
    PhoneNumberCodeTypeVerify,
    PhoneNumberCodeTypeConfirmOwnership,
    LogStreamDefault,
    LogStreamFile,
    LogStreamEmpty,
    LogVerbosityLevel,
    LogTags,
    UserSupportInfo,
    TestInt,
    TestString,
    TestBytes,
    TestVectorInt,
    TestVectorIntObject,
    TestVectorString,
    TestVectorStringObject,
    UpdateAuthorizationState,
    UpdateNewMessage,
    UpdateMessageSendAcknowledged,
    UpdateMessageSendSucceeded,
    UpdateMessageSendFailed,
    UpdateMessageContent,
    UpdateMessageEdited,
    UpdateMessageIsPinned,
    UpdateMessageInteractionInfo,
    UpdateMessageContentOpened,
    UpdateMessageMentionRead,
    UpdateMessageUnreadReactions,
    UpdateMessageFactCheck,
    UpdateMessageSuggestedPostInfo,
    UpdateMessageLiveLocationViewed,
    UpdateVideoPublished,
    UpdateNewChat,
    UpdateChatTitle,
    UpdateChatPhoto,
    UpdateChatAccentColors,
    UpdateChatPermissions,
    UpdateChatLastMessage,
    UpdateChatPosition,
    UpdateChatAddedToList,
    UpdateChatRemovedFromList,
    UpdateChatReadInbox,
    UpdateChatReadOutbox,
    UpdateChatActionBar,
    UpdateChatBusinessBotManageBar,
    UpdateChatAvailableReactions,
    UpdateChatDraftMessage,
    UpdateChatEmojiStatus,
    UpdateChatMessageSender,
    UpdateChatMessageAutoDeleteTime,
    UpdateChatNotificationSettings,
    UpdateChatPendingJoinRequests,
    UpdateChatReplyMarkup,
    UpdateChatBackground,
    UpdateChatTheme,
    UpdateChatUnreadMentionCount,
    UpdateChatUnreadReactionCount,
    UpdateChatVideoChat,
    UpdateChatDefaultDisableNotification,
    UpdateChatHasProtectedContent,
    UpdateChatIsTranslatable,
    UpdateChatIsMarkedAsUnread,
    UpdateChatViewAsTopics,
    UpdateChatBlockList,
    UpdateChatHasScheduledMessages,
    UpdateChatFolders,
    UpdateChatOnlineMemberCount,
    UpdateSavedMessagesTopic,
    UpdateSavedMessagesTopicCount,
    UpdateDirectMessagesChatTopic,
    UpdateTopicMessageCount,
    UpdateQuickReplyShortcut,
    UpdateQuickReplyShortcutDeleted,
    UpdateQuickReplyShortcuts,
    UpdateQuickReplyShortcutMessages,
    UpdateForumTopicInfo,
    UpdateForumTopic,
    UpdateScopeNotificationSettings,
    UpdateReactionNotificationSettings,
    UpdateNotification,
    UpdateNotificationGroup,
    UpdateActiveNotifications,
    UpdateHavePendingNotifications,
    UpdateDeleteMessages,
    UpdateChatAction,
    UpdateUserStatus,
    UpdateUser,
    UpdateBasicGroup,
    UpdateSupergroup,
    UpdateSecretChat,
    UpdateUserFullInfo,
    UpdateBasicGroupFullInfo,
    UpdateSupergroupFullInfo,
    UpdateServiceNotification,
    UpdateFile,
    UpdateFileGenerationStart,
    UpdateFileGenerationStop,
    UpdateFileDownloads,
    UpdateFileAddedToDownloads,
    UpdateFileDownload,
    UpdateFileRemovedFromDownloads,
    UpdateApplicationVerificationRequired,
    UpdateApplicationRecaptchaVerificationRequired,
    UpdateCall,
    UpdateGroupCall,
    UpdateGroupCallParticipant,
    UpdateGroupCallParticipants,
    UpdateGroupCallVerificationState,
    UpdateNewCallSignalingData,
    UpdateUserPrivacySettingRules,
    UpdateUnreadMessageCount,
    UpdateUnreadChatCount,
    UpdateStory,
    UpdateStoryDeleted,
    UpdateStoryPostSucceeded,
    UpdateStoryPostFailed,
    UpdateChatActiveStories,
    UpdateStoryListChatCount,
    UpdateStoryStealthMode,
    UpdateOption,
    UpdateStickerSet,
    UpdateInstalledStickerSets,
    UpdateTrendingStickerSets,
    UpdateRecentStickers,
    UpdateFavoriteStickers,
    UpdateSavedAnimations,
    UpdateSavedNotificationSounds,
    UpdateDefaultBackground,
    UpdateEmojiChatThemes,
    UpdateAccentColors,
    UpdateProfileAccentColors,
    UpdateLanguagePackStrings,
    UpdateConnectionState,
    UpdateFreezeState,
    UpdateAgeVerificationParameters,
    UpdateTermsOfService,
    UpdateUnconfirmedSession,
    UpdateAttachmentMenuBots,
    UpdateWebAppMessageSent,
    UpdateActiveEmojiReactions,
    UpdateAvailableMessageEffects,
    UpdateDefaultReactionType,
    UpdateDefaultPaidReactionType,
    UpdateSavedMessagesTags,
    UpdateActiveLiveLocationMessages,
    UpdateOwnedStarCount,
    UpdateOwnedTonCount,
    UpdateChatRevenueAmount,
    UpdateStarRevenueStatus,
    UpdateTonRevenueStatus,
    UpdateSpeechRecognitionTrial,
    UpdateDiceEmojis,
    UpdateAnimatedEmojiMessageClicked,
    UpdateAnimationSearchParameters,
    UpdateSuggestedActions,
    UpdateSpeedLimitNotification,
    UpdateContactCloseBirthdays,
    UpdateAutosaveSettings,
    UpdateBusinessConnection,
    UpdateNewBusinessMessage,
    UpdateBusinessMessageEdited,
    UpdateBusinessMessagesDeleted,
    UpdateNewInlineQuery,
    UpdateNewChosenInlineResult,
    UpdateNewCallbackQuery,
    UpdateNewInlineCallbackQuery,
    UpdateNewBusinessCallbackQuery,
    UpdateNewShippingQuery,
    UpdateNewPreCheckoutQuery,
    UpdateNewCustomEvent,
    UpdateNewCustomQuery,
    UpdatePoll,
    UpdatePollAnswer,
    UpdateChatMember,
    UpdateNewChatJoinRequest,
    UpdateChatBoost,
    UpdateMessageReaction,
    UpdateMessageReactions,
    UpdatePaidMediaPurchased,
    Updates,
)
from .plugins import Plugins
from .tdserver import ServerStats, ScheduledEvent, UpdateScheduledEvent

TDLIB_VERSION = "1.8.55"
